#
from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_1 = {
    "Non-fiction books about Indigenous peoples of the Americas": "كتب غير خيالية عن شعوب أصلية في الأمريكتين",
    "19th-century non-fiction writers by nationality": "كتاب غير روائيين في القرن 19 حسب الجنسية",
    "19th-century non-fiction writers from the Russian Empire": "كتاب غير روائيين من الإمبراطورية الروسية في القرن 19",
    "20th-century non-fiction writers by nationality": "كتاب غير روائيين في القرن 20 حسب الجنسية",
    "21st-century non-fiction writers by nationality": "كتاب غير روائيين في القرن 21 حسب الجنسية",
    "African-American non-fiction writers": "كتاب غير روائيين أمريكيون أفارقة",
    "Cameroonian non-fiction writers": "كتاب غير روائيين كاميرونيون",
    "Canadian non-fiction writers in French": "كتاب غير روائيين كنديون في فرنسيون",
    "Non-fiction writers about organized crime in Italy": "كتاب غير روائيين عن جريمة منظمة في إيطاليا",
    "Non-fiction writers about organized crime in the United States": "كتاب غير روائيين عن جريمة منظمة في الولايات المتحدة",
    "Paraguayan non-fiction writers": "كتاب غير روائيين بارغوايانيون",
    "Togolese non-fiction writers": "كتاب غير روائيين توغويون",
    "Zimbabwean non-fiction writers": "كتاب غير روائيين زيمبابويون",
    "10th-century non-fiction writers": "كتاب غير روائيين في القرن 10",
    "11th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 11",
    "11th-century non-fiction writers": "كتاب غير روائيين في القرن 11",
    "12th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 12",
    "12th-century non-fiction writers": "كتاب غير روائيين في القرن 12",
    "13th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 13",
    "13th-century non-fiction writers": "كتاب غير روائيين في القرن 13",
    "14th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 14",
    "14th-century non-fiction writers": "كتاب غير روائيين في القرن 14",
    "15th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 15",
    "15th-century non-fiction writers": "كتاب غير روائيين في القرن 15",
    "16th-century Danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 16",
    "16th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 16",
    "16th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 16",
    "16th-century non-fiction writers": "كتاب غير روائيين في القرن 16",
    "17th-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 17",
    "17th-century Danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 17",
    "17th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 17",
    "17th-century French non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 17",
    "17th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 17",
    "17th-century non-fiction writers": "كتاب غير روائيين في القرن 17",
    "18th-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 18",
    "18th-century British non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 18",
    "18th-century Canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 18",
    "18th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 18",
    "18th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 18",
    "18th-century non-fiction writers": "كتاب غير روائيين في القرن 18",
    "19th-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 19",
    "19th-century British non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 19",
    "19th-century Canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 19",
    "19th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 19",
    "19th-century French non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 19",
    "19th-century German non-fiction writers": "كتاب غير روائيين ألمان في القرن 19",
    "19th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 19",
    "19th-century Irish non-fiction writers": "كتاب غير روائيين أيرلنديون في القرن 19",
    "19th-century non-fiction writers": "كتاب غير روائيين في القرن 19",
    "20th-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 20",
    "20th-century Australian non-fiction writers": "كتاب غير روائيين أستراليون في القرن 20",
    "20th-century Belgian non-fiction writers": "كتاب غير روائيين بلجيكيون في القرن 20",
    "20th-century British non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 20",
    "20th-century Canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 20",
    "20th-century Chilean non-fiction writers": "كتاب غير روائيين تشيليون في القرن 20",
    "20th-century Croatian non-fiction writers": "كتاب غير روائيين كروات في القرن 20",
    "20th-century Danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 20",
    "20th-century Dutch non-fiction writers": "كتاب غير روائيين هولنديون في القرن 20",
    "20th-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 20",
    "20th-century French non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 20",
    "20th-century German non-fiction writers": "كتاب غير روائيين ألمان في القرن 20",
    "20th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 20",
    "20th-century Irish non-fiction writers": "كتاب غير روائيين أيرلنديون في القرن 20",
    "20th-century Israeli non-fiction writers": "كتاب غير روائيين إسرائيليون في القرن 20",
    "20th-century Italian non-fiction writers": "كتاب غير روائيين إيطاليون في القرن 20",
    "20th-century Lithuanian non-fiction writers": "كتاب غير روائيين ليتوانيون في القرن 20",
    "20th-century Norwegian non-fiction writers": "كتاب غير روائيين نرويجيون في القرن 20",
    "20th-century Polish non-fiction writers": "كتاب غير روائيين بولنديون في القرن 20",
    "20th-century Russian non-fiction writers": "كتاب غير روائيين روس في القرن 20",
    "20th-century Swedish non-fiction writers": "كتاب غير روائيين سويديون في القرن 20",
    "20th-century Swiss non-fiction writers": "كتاب غير روائيين سويسريون في القرن 20",
    "20th-century non-fiction writers": "كتاب غير روائيين في القرن 20",
    "21st-century American non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 21",
    "21st-century Australian non-fiction writers": "كتاب غير روائيين أستراليون في القرن 21",
    "21st-century Belgian non-fiction writers": "كتاب غير روائيين بلجيكيون في القرن 21",
    "21st-century British non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 21",
    "21st-century Canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 21",
    "21st-century Chilean non-fiction writers": "كتاب غير روائيين تشيليون في القرن 21",
    "21st-century Croatian non-fiction writers": "كتاب غير روائيين كروات في القرن 21",
    "21st-century Danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 21",
    "21st-century Dutch non-fiction writers": "كتاب غير روائيين هولنديون في القرن 21",
    "21st-century English non-fiction writers": "كتاب غير روائيين إنجليز في القرن 21",
    "21st-century Finnish non-fiction writers": "كتاب غير روائيين فنلنديون في القرن 21",
    "21st-century French non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 21",
    "21st-century German non-fiction writers": "كتاب غير روائيين ألمان في القرن 21",
    "21st-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 21",
    "21st-century Irish non-fiction writers": "كتاب غير روائيين أيرلنديون في القرن 21",
    "21st-century Israeli non-fiction writers": "كتاب غير روائيين إسرائيليون في القرن 21",
    "21st-century Italian non-fiction writers": "كتاب غير روائيين إيطاليون في القرن 21",
    "21st-century Polish non-fiction writers": "كتاب غير روائيين بولنديون في القرن 21",
    "21st-century Russian non-fiction writers": "كتاب غير روائيين روس في القرن 21",
    "21st-century Scottish non-fiction writers": "كتاب غير روائيين إسكتلنديون في القرن 21",
    "21st-century Spanish non-fiction writers": "كتاب غير روائيين إسبان في القرن 21",
    "21st-century Swiss non-fiction writers": "كتاب غير روائيين سويسريون في القرن 21",
    "21st-century non-fiction writers": "كتاب غير روائيين في القرن 21",
    "21st-century non-fiction writers from Northern Ireland": "كتاب غير روائيين من أيرلندا الشمالية في القرن 21",
    "2nd-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 2",
    "2nd-century non-fiction writers": "كتاب غير روائيين في القرن 2",
    "3rd-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 3",
    "3rd-century non-fiction writers": "كتاب غير روائيين في القرن 3",
    "4th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 4",
    "4th-century non-fiction writers": "كتاب غير روائيين في القرن 4",
    "5th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 5",
    "5th-century non-fiction writers": "كتاب غير روائيين في القرن 5",
    "6th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 6",
    "6th-century non-fiction writers": "كتاب غير روائيين في القرن 6",
    "7th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 7",
    "7th-century non-fiction writers": "كتاب غير روائيين في القرن 7",
    "8th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 8",
    "8th-century non-fiction writers": "كتاب غير روائيين في القرن 8",
    "9th-century Indian non-fiction writers": "كتاب غير روائيين هنود في القرن 9",
    "9th-century non-fiction writers": "كتاب غير روائيين في القرن 9",
    "Albanian non-fiction writers": "كتاب غير روائيين ألبان",
    "American male non-fiction writers": "كتاب غير روائيين ذكور أمريكيون",
    "American non-fiction crime writers": "كتاب جريمة غير روائيين أمريكيون",
    "American non-fiction environmental writers": "كتاب بيئة غير روائيين أمريكيون",
    "American non-fiction writers": "كتاب غير روائيين أمريكيون",
    "American non-fiction writers by century": "كتاب غير روائيين أمريكيون حسب القرن",
    "Angolan non-fiction writers": "كتاب غير روائيين أنغوليون",
    "Arab non-fiction writers": "كتاب غير روائيين عرب",
    "Argentine non-fiction writers": "كتاب غير روائيين أرجنتينيون",
    "Armenian non-fiction writers": "كتاب غير روائيين أرمن",
    "Australian male non-fiction writers": "كتاب غير روائيين ذكور أستراليون",
    "Australian non-fiction crime writers": "كتاب جريمة غير روائيين أستراليون",
    "Australian non-fiction writers": "كتاب غير روائيين أستراليون",
    "Austrian non-fiction writers": "كتاب غير روائيين نمساويون",
    "Azerbaijani non-fiction writers": "كتاب غير روائيين أذربيجانيون",
    "Bangladeshi non-fiction writers": "كتاب غير روائيين بنغلاديشيون",
    "Belarusian non-fiction writers": "كتاب غير روائيين بيلاروسيون",
    "Belgian male non-fiction writers": "كتاب غير روائيين ذكور بلجيكيون",
    "Belgian non-fiction writers": "كتاب غير روائيين بلجيكيون",
    "Belgian non-fiction writers by century": "كتاب غير روائيين بلجيكيون حسب القرن",
    "Beninese non-fiction writers": "كتاب غير روائيين بنينيون",
    "Bermudian non-fiction writers": "كتاب غير روائيين برموديون",
    "Bolivian non-fiction writers": "كتاب غير روائيين بوليفيون",
    "Bosnia and Herzegovina non-fiction writers": "كتاب غير روائيين بوسنيون",
    "Botswana non-fiction writers": "كتاب غير روائيين بوتسوانيون",
    "Brazilian non-fiction writers": "كتاب غير روائيين برازيليون",
    "British male non-fiction writers": "كتاب غير روائيين ذكور بريطانيون",
    "British non-fiction crime writers": "كتاب جريمة غير روائيين بريطانيون",
    "British non-fiction writers": "كتاب غير روائيين بريطانيون",
    "British non-fiction writers by century": "كتاب غير روائيين بريطانيون حسب القرن",
    "Burkinabe non-fiction writers": "كتاب غير روائيين بوركينابيون",
    "Burkinabé non-fiction writers": "كتاب غير روائيين بوركينابيون",
    "Burmese non-fiction writers": "كتاب غير روائيين بورميون",
    "Canadian male non-fiction writers": "كتاب غير روائيين ذكور كنديون",
    "Canadian non-fiction writers": "كتاب غير روائيين كنديون",
    "Canadian non-fiction writers by century": "كتاب غير روائيين كنديون حسب القرن",
    "Central African Republic non-fiction writers": "كتاب غير روائيين أفارقة أوسطيون",
    "Chadian non-fiction writers": "كتاب غير روائيين تشاديون",
    "Chilean non-fiction writers": "كتاب غير روائيين تشيليون",
    "Chinese non-fiction writers": "كتاب غير روائيين صينيون",
    "Colombian non-fiction writers": "كتاب غير روائيين كولومبيون",
    "Croatian non-fiction writers by century": "كتاب غير روائيين كروات حسب القرن",
    "Cuban non-fiction writers": "كتاب غير روائيين كوبيون",
    "Cypriot non-fiction writers": "كتاب غير روائيين قبرصيون",
    "Czech non-fiction writers": "كتاب غير روائيين تشيكيون",
    "Danish male non-fiction writers": "كتاب غير روائيين ذكور دنماركيون",
    "Danish non-fiction writers": "كتاب غير روائيين دنماركيون",
    "Danish non-fiction writers by century": "كتاب غير روائيين دنماركيون حسب القرن",
    "Democratic republic of congo non-fiction writers": "كتاب غير روائيين كونغويون ديمقراطيون",
    "Dutch non-fiction writers": "كتاب غير روائيين هولنديون",
    "Dutch non-fiction writers by century": "كتاب غير روائيين هولنديون حسب القرن",
    "Egyptian non-fiction writers": "كتاب غير روائيين مصريون",
    "Emirati non-fiction writers": "كتاب غير روائيين إماراتيون",
    "English male non-fiction writers": "كتاب غير روائيين ذكور إنجليز",
    "English non-fiction crime writers": "كتاب جريمة غير روائيين إنجليز",
    "English non-fiction writers by century": "كتاب غير روائيين إنجليز حسب القرن",
    "Eritrean non-fiction writers": "كتاب غير روائيين إريتريون",
    "Estonian non-fiction writers": "كتاب غير روائيين إستونيون",
    "Ethiopian non-fiction writers": "كتاب غير روائيين إثيوبيون",
    "Filipino non-fiction writers": "كتاب غير روائيين فلبينيون",
    "Finnish non-fiction writers": "كتاب غير روائيين فنلنديون",
    "Finnish non-fiction writers by century": "كتاب غير روائيين فنلنديون حسب القرن",
    "French male non-fiction writers": "كتاب غير روائيين ذكور فرنسيون",
    "French non-fiction writers": "كتاب غير روائيين فرنسيون",
    "French non-fiction writers by century": "كتاب غير روائيين فرنسيون حسب القرن",
    "Gambian non-fiction writers": "كتاب غير روائيين غامبيون",
    "German male non-fiction writers": "كتاب غير روائيين ذكور ألمان",
    "German non-fiction writers": "كتاب غير روائيين ألمان",
    "German non-fiction writers by century": "كتاب غير روائيين ألمان حسب القرن",
    "Ghanaian non-fiction writers": "كتاب غير روائيين غانيون",
    "Greek non-fiction writers": "كتاب غير روائيين يونانيون",
    "Guadeloupean non-fiction writers": "كتاب غير روائيين غواديلوبيون",
    "Guyanese non-fiction writers": "كتاب غير روائيين غيانيون",
    "Haitian non-fiction writers": "كتاب غير روائيين هايتيون",
    "Hungarian non-fiction writers": "كتاب غير روائيين مجريون",
    "Icelandic non-fiction writers": "كتاب غير روائيين آيسلنديون",
    "Indian male non-fiction writers": "كتاب غير روائيين ذكور هنود",
    "Indian non-fiction environmental writers": "كتاب بيئة غير روائيين هنود",
    "Indian non-fiction writers": "كتاب غير روائيين هنود",
    "Indian non-fiction writers by century": "كتاب غير روائيين هنود حسب القرن",
    "Indonesian non-fiction writers": "كتاب غير روائيين إندونيسيون",
    "Iranian non-fiction writers": "كتاب غير روائيين إيرانيون",
    "Iraqi non-fiction writers": "كتاب غير روائيين عراقيون",
    "Irish male non-fiction writers": "كتاب غير روائيين ذكور أيرلنديون",
    "Irish non-fiction writers": "كتاب غير روائيين أيرلنديون",
    "Irish non-fiction writers by century": "كتاب غير روائيين أيرلنديون حسب القرن",
    "Israeli non-fiction writers": "كتاب غير روائيين إسرائيليون",
    "Israeli non-fiction writers by century": "كتاب غير روائيين إسرائيليون حسب القرن",
    "Italian male non-fiction writers": "كتاب غير روائيين ذكور إيطاليون",
    "Italian non-fiction writers": "كتاب غير روائيين إيطاليون",
    "Italian non-fiction writers by century": "كتاب غير روائيين إيطاليون حسب القرن",
    "Jamaican non-fiction writers": "كتاب غير روائيين جامايكيون",
    "Japanese non-fiction writers": "كتاب غير روائيين يابانيون",
    "Japanese non-fiction writers by century": "كتاب غير روائيين يابانيون حسب القرن",
    "Jewish American non-fiction writers": "كتاب غير روائيين أمريكيون يهود",
    "Jewish non-fiction writers": "كتاب غير روائيين يهود",
    "Kenyan non-fiction writers": "كتاب غير روائيين كينيون",
    "Korean non-fiction writers": "كتاب غير روائيين كوريون",
    "Kosovan non-fiction writers": "كتاب غير روائيين كوسوفيون",
    "Kuwaiti non-fiction writers": "كتاب غير روائيين كويتيون",
    "Latvian non-fiction writers": "كتاب غير روائيين لاتفيون",
    "Lebanese non-fiction writers": "كتاب غير روائيين لبنانيون",
    "Liberian non-fiction writers": "كتاب غير روائيين ليبيريون",
    "Libyan non-fiction writers": "كتاب غير روائيين ليبيون",
    "Lithuanian non-fiction writers": "كتاب غير روائيين ليتوانيون",
    "Luxembourgian non-fiction writers": "كتاب غير روائيين لوكسمبورغيون",
    "Macedonian non-fiction writers": "كتاب غير روائيين مقدونيون",
    "Malawian non-fiction writers": "كتاب غير روائيين ملاويون",
    "Malaysian non-fiction writers": "كتاب غير روائيين ماليزيون",
    "Male non-fiction writers": "كتاب غير روائيين ذكور",
    "Male non-fiction writers by nationality": "كتاب غير روائيين ذكور حسب الجنسية",
    "Male non-fiction writers from Northern Ireland": "كتاب غير روائيين ذكور من أيرلندا الشمالية",
    "Malian non-fiction writers": "كتاب غير روائيين ماليون",
    "Maltese non-fiction writers": "كتاب غير روائيين مالطيون",
    "Mauritian non-fiction writers": "كتاب غير روائيين موريشيوسيون",
    "Mexican non-fiction writers": "كتاب غير روائيين مكسيكيون",
    "Moroccan non-fiction writers": "كتاب غير روائيين مغاربة",
    "Mozambican non-fiction writers": "كتاب غير روائيين موزمبيقيون",
    "Namibian non-fiction writers": "كتاب غير روائيين ناميبيون",
    "Nigerian non-fiction writers": "كتاب غير روائيين نيجيريون",
    "Non-fiction crime writers": "كتاب جريمة غير روائيين",
    "Non-fiction environmental writers": "كتاب بيئة غير روائيين",
    "Non-fiction writers": "كتاب غير روائيين",
    "Non-fiction writers by century": "كتاب غير روائيين حسب القرن",
    "Non-fiction writers by century and nationality": "كتاب غير روائيين حسب القرن والجنسية",
    "Non-fiction writers by nationality": "كتاب غير روائيين حسب الجنسية",
    "Non-fiction writers by nationality and century": "كتاب غير روائيين حسب الجنسية والقرن",
    "Non-fiction writers from Cornwall": "كتاب غير روائيين من كورنوال",
    "Non-fiction writers from Georgia (country)": "كتاب غير روائيين من جورجيا",
    "Non-fiction writers from Northern Ireland": "كتاب غير روائيين من أيرلندا الشمالية",
    "Non-fiction writers from the Ottoman Empire": "كتاب غير روائيين من الدولة العثمانية",
    "Non-fiction writers from the Russian Empire": "كتاب غير روائيين من الإمبراطورية الروسية",
    "Norwegian non-fiction writers": "كتاب غير روائيين نرويجيون",
    "Norwegian non-fiction writers by century": "كتاب غير روائيين نرويجيون حسب القرن",
    "Pakistani non-fiction writers": "كتاب غير روائيين باكستانيون",
    "Pakistani non-fiction writers by century": "كتاب غير روائيين باكستانيون حسب القرن",
    "Palestinian non-fiction writers": "كتاب غير روائيين فلسطينيون",
    "Peruvian non-fiction writers": "كتاب غير روائيين بيرويون",
    "Polish male non-fiction writers": "كتاب غير روائيين ذكور بولنديون",
    "Polish non-fiction writers": "كتاب غير روائيين بولنديون",
    "Portuguese non-fiction writers": "كتاب غير روائيين برتغاليون",
    "Puerto Rican non-fiction writers": "كتاب غير روائيين بورتوريكيون",
    "Qatari non-fiction writers": "كتاب غير روائيين قطريون",
    "Romanian non-fiction writers": "كتاب غير روائيين رومان",
    "Russian non-fiction writers": "كتاب غير روائيين روس",
    "Russian non-fiction writers by century": "كتاب غير روائيين روس حسب القرن",
    "Rwandan non-fiction writers": "كتاب غير روائيين روانديون",
    "Sahrawi non-fiction writers": "كتاب غير روائيين صحراويون",
    "Saudi Arabian non-fiction writers": "كتاب غير روائيين سعوديون",
    "Scottish non-fiction writers": "كتاب غير روائيين إسكتلنديون",
    "Scottish non-fiction writers by century": "كتاب غير روائيين إسكتلنديون حسب القرن",
    "Senegalese non-fiction writers": "كتاب غير روائيين سنغاليون",
    "Serbian non-fiction writers": "كتاب غير روائيين صرب",
    "Sierra Leonean non-fiction writers": "كتاب غير روائيين سيراليونيون",
    "Singaporean non-fiction writers": "كتاب غير روائيين سنغافوريون",
    "Slovak non-fiction writers": "كتاب غير روائيين سلوفاكيون",
    "Slovenian non-fiction writers": "كتاب غير روائيين سلوفينيون",
    "Somalian non-fiction writers": "كتاب غير روائيين صوماليون",
    "South Korean non-fiction writers": "كتاب غير روائيين كوريون جنوبيون",
    "Soviet non-fiction writers": "كتاب غير روائيين سوفيت",
    "Spanish male non-fiction writers": "كتاب غير روائيين ذكور إسبان",
    "Spanish non-fiction writers": "كتاب غير روائيين إسبان",
    "Spanish non-fiction writers by century": "كتاب غير روائيين إسبان حسب القرن",
    "Sri Lankan non-fiction writers": "كتاب غير روائيين سريلانكيون",
    "Sudanese non-fiction writers": "كتاب غير روائيين سودانيون",
    "Swedish male non-fiction writers": "كتاب غير روائيين ذكور سويديون",
    "Swedish non-fiction writers": "كتاب غير روائيين سويديون",
    "Swedish non-fiction writers by century": "كتاب غير روائيين سويديون حسب القرن",
    "Swiss non-fiction writers": "كتاب غير روائيين سويسريون",
    "Swiss non-fiction writers by century": "كتاب غير روائيين سويسريون حسب القرن",
    "Syrian non-fiction writers": "كتاب غير روائيين سوريون",
    "Taiwanese non-fiction writers": "كتاب غير روائيين تايوانيون",
    "Tajikistani non-fiction writers": "كتاب غير روائيين طاجيك",
    "Tanzanian non-fiction writers": "كتاب غير روائيين تنزانيون",
    "Thai non-fiction writers": "كتاب غير روائيين تايلنديون",
    "Trinidad and Tobago non-fiction writers": "كتاب غير روائيين ترنيداديون",
    "Tunisian non-fiction writers": "كتاب غير روائيين تونسيون",
    "Turkish Cypriot non-fiction writers": "كتاب غير روائيين قبرصيون شماليون",
    "Turkish non-fiction writers": "كتاب غير روائيين أتراك",
    "Ugandan non-fiction writers": "كتاب غير روائيين أوغنديون",
    "Ukrainian non-fiction writers": "كتاب غير روائيين أوكرانيون",
    "Uruguayan non-fiction writers": "كتاب غير روائيين أوروغويانيون",
    "Venezuelan non-fiction writers": "كتاب غير روائيين فنزويليون",
    "Vietnamese non-fiction writers": "كتاب غير روائيين فيتناميون",
    "Yemeni non-fiction writers": "كتاب غير روائيين يمنيون",
    "Yugoslav non-fiction writers": "كتاب غير روائيين يوغسلافيون",
    "Zambian non-fiction writers": "كتاب غير روائيين زامبيون",
}

to_test = [
    ("text_non_fiction", data_1),
]

test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)



#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

test_lutenists_1 = {
    "Lutenists": "عازفو آلات وترية",
    "German lutenists": "عازفو آلات وترية ألمان",
    "American lutenists": "عازفو آلات وترية أمريكيون",
    "Spanish lutenists": "عازفو آلات وترية إسبان",
    "English lutenists": "عازفو آلات وترية إنجليز",
    "Portuguese lutenists": "عازفو آلات وترية برتغاليون",
    "British lutenists": "عازفو آلات وترية بريطانيون",
    "Polish lutenists": "عازفو آلات وترية بولنديون",
    "Lutenists by nationality": "عازفو آلات وترية حسب الجنسية",
    "Danish lutenists": "عازفو آلات وترية دنماركيون",
    "Russian lutenists": "عازفو آلات وترية روس",
    "French lutenists": "عازفو آلات وترية فرنسيون",
    "Dutch lutenists": "عازفو آلات وترية هولنديون",
}
to_test = [
    ("test_lutenists_1", test_lutenists_1),
]


@pytest.mark.parametrize("category, expected", test_lutenists_1.items(), ids=test_lutenists_1.keys())
@pytest.mark.fast
def test_data_lutenists_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)



from .Nationality import (
    All_Nat,
    Nat_men,
    Nat_mens,
    Nat_the_female,
    Nat_the_male,
    Nat_women,
    Nat_Womens,
    NationalityEntry,
    all_country_ar,
    all_country_with_nat,
    all_country_with_nat_ar,
    all_nat_sorted,
    ar_Nat_men,
    countries_en_as_nationality_keys,
    countries_from_nat,
    countries_nat_en_key,
    en_nats_to_ar_label,
    raw_nats_as_en_key,
)

__all__ = [
    "All_Nat",
    "Nat_men",
    "Nat_mens",
    "Nat_the_female",
    "Nat_the_male",
    "Nat_women",
    "Nat_Womens",
    "NationalityEntry",
    "all_country_ar",
    "all_country_with_nat",
    "all_country_with_nat_ar",
    "all_nat_sorted",
    "ar_Nat_men",
    "countries_en_as_nationality_keys",
    "countries_from_nat",
    "countries_nat_en_key",
    "en_nats_to_ar_label",
    "raw_nats_as_en_key",
]



"""
Utility functions for gender-related category resolution.
This module provides functions to normalize and standardize gender-specific
terms in category keys before they are matched by resolvers.
"""

import functools
import re

REGEX_WOMENS = re.compile(r"\b(womens|women)\b", re.I)  # replaced by female
REGEX_MENS = re.compile(r"\b(mens|men)\b", re.I)  # replaced by male


@functools.lru_cache(maxsize=10000)
def fix_keys(category: str) -> str:
    category = category.lower().replace("category:", "")
    category = category.replace("'", "")

    replacements = {
        "expatriates": "expatriate",
        "canadian football": "canadian-football",
        "american football": "american-football",
    }

    for old, new in replacements.items():
        category = category.replace(old, new)

    category = REGEX_WOMENS.sub("female", category)
    category = REGEX_MENS.sub("male", category)

    return category.strip()



#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data1 = {}

data2 = {
    "1964 in American women's sports": "رياضات نسائية أمريكية في 1964",
    "1972 in American women's sports": "رياضات نسائية أمريكية في 1972",
    "2003 in Canadian women's sports": "رياضات نسائية كندية في 2003",
    "2026 in American women's sports": "رياضات نسائية أمريكية في 2026",
    "american women's sports": "رياضات نسائية أمريكية",
    "canadian women's sports": "رياضات نسائية كندية",
    "mexican women's sports": "رياضات نسائية مكسيكية",
    "1550 in sports": "ألعاب رياضية في 1550",
    "december 1550 in sports": "ألعاب رياضية في ديسمبر 1550",
    "june 1550 in sports": "ألعاب رياضية في يونيو 1550",
    "Sports leagues in Papua New Guinea": "دوريات رياضية في بابوا غينيا الجديدة",
    "honduran people in sports": "هندوراسيون في ألعاب رياضية",
    "Jewish sports": "ألعاب رياضية يهودية",
    "surinamese sports federation": "الاتحاد السورينامي للرياضة",
    "zaïrean wheelchair sports federation": "الاتحاد الزائيري للرياضة على الكراسي المتحركة",
    "American women's sports by year": "رياضات نسائية أمريكية حسب السنة",
    "American women's sports by decade": "رياضات نسائية أمريكية حسب العقد",
    "1887 in American women's sports": "رياضات نسائية أمريكية في 1887",
    "1889 in American women's sports": "رياضات نسائية أمريكية في 1889",
    "1930 in American women's sports": "رياضات نسائية أمريكية في 1930",
    "1931 in American women's sports": "رياضات نسائية أمريكية في 1931",
    "1934 in American women's sports": "رياضات نسائية أمريكية في 1934",
    "1938 in American women's sports": "رياضات نسائية أمريكية في 1938",
    "1945 in American women's sports": "رياضات نسائية أمريكية في 1945",
    "1946 in American women's sports": "رياضات نسائية أمريكية في 1946",
    "1947 in American women's sports": "رياضات نسائية أمريكية في 1947",
    "1948 in American women's sports": "رياضات نسائية أمريكية في 1948",
    "1950 in American women's sports": "رياضات نسائية أمريكية في 1950",
    "1951 in American women's sports": "رياضات نسائية أمريكية في 1951",
    "1953 in American women's sports": "رياضات نسائية أمريكية في 1953",
    "1954 in American women's sports": "رياضات نسائية أمريكية في 1954",
    "1955 in American women's sports": "رياضات نسائية أمريكية في 1955",
    "1956 in American women's sports": "رياضات نسائية أمريكية في 1956",
    "1959 in American women's sports": "رياضات نسائية أمريكية في 1959",
    "1961 in American women's sports": "رياضات نسائية أمريكية في 1961",
    "1963 in American women's sports": "رياضات نسائية أمريكية في 1963",
    "1966 in American women's sports": "رياضات نسائية أمريكية في 1966",
    "1967 in American women's sports": "رياضات نسائية أمريكية في 1967",
    "1968 in American women's sports": "رياضات نسائية أمريكية في 1968",
    "1970 in American women's sports": "رياضات نسائية أمريكية في 1970",
    "1971 in American women's sports": "رياضات نسائية أمريكية في 1971",
    "1973 in American women's sports": "رياضات نسائية أمريكية في 1973",
    "1974 in American women's sports": "رياضات نسائية أمريكية في 1974",
    "1975 in American women's sports": "رياضات نسائية أمريكية في 1975",
    "1978 in American women's sports": "رياضات نسائية أمريكية في 1978",
    "1979 in American women's sports": "رياضات نسائية أمريكية في 1979",
    "1980 in American women's sports": "رياضات نسائية أمريكية في 1980",
    "1982 in American women's sports": "رياضات نسائية أمريكية في 1982",
    "1983 in American women's sports": "رياضات نسائية أمريكية في 1983",
    "1984 in American women's sports": "رياضات نسائية أمريكية في 1984",
    "1985 in American women's sports": "رياضات نسائية أمريكية في 1985",
    "1986 in American women's sports": "رياضات نسائية أمريكية في 1986",
    "1987 in American women's sports": "رياضات نسائية أمريكية في 1987",
    "1989 in American women's sports": "رياضات نسائية أمريكية في 1989",
    "1990 in American women's sports": "رياضات نسائية أمريكية في 1990",
    "1991 in American women's sports": "رياضات نسائية أمريكية في 1991",
    "1992 in American women's sports": "رياضات نسائية أمريكية في 1992",
    "1993 in American women's sports": "رياضات نسائية أمريكية في 1993",
    "1995 in American women's sports": "رياضات نسائية أمريكية في 1995",
    "1996 in American women's sports": "رياضات نسائية أمريكية في 1996",
    "1998 in American women's sports": "رياضات نسائية أمريكية في 1998",
    "2000 in American women's sports": "رياضات نسائية أمريكية في 2000",
    "2001 in American women's sports": "رياضات نسائية أمريكية في 2001",
    "2004 in American women's sports": "رياضات نسائية أمريكية في 2004",
    "2005 in American women's sports": "رياضات نسائية أمريكية في 2005",
    "2006 in American women's sports": "رياضات نسائية أمريكية في 2006",
    "2007 in American women's sports": "رياضات نسائية أمريكية في 2007",
    "2009 in American women's sports": "رياضات نسائية أمريكية في 2009",
    "2010 in American women's sports": "رياضات نسائية أمريكية في 2010",
    "2011 in American women's sports": "رياضات نسائية أمريكية في 2011",
    "2012 in American women's sports": "رياضات نسائية أمريكية في 2012",
    "2013 in American women's sports": "رياضات نسائية أمريكية في 2013",
    "2014 in American women's sports": "رياضات نسائية أمريكية في 2014",
    "2015 in American women's sports": "رياضات نسائية أمريكية في 2015",
    "2016 in American women's sports": "رياضات نسائية أمريكية في 2016",
    "2017 in American women's sports": "رياضات نسائية أمريكية في 2017",
    "2018 in American women's sports": "رياضات نسائية أمريكية في 2018",
    "2021 in American women's sports": "رياضات نسائية أمريكية في 2021",
    "2022 in American women's sports": "رياضات نسائية أمريكية في 2022",
    "2023 in American women's sports": "رياضات نسائية أمريكية في 2023",
    "2024 in American women's sports": "رياضات نسائية أمريكية في 2024",
    "2025 in American women's sports": "رياضات نسائية أمريكية في 2025",
    "1880s in American women's sports": "رياضات نسائية أمريكية في عقد 1880",
    "1930s in American women's sports": "رياضات نسائية أمريكية في عقد 1930",
    "1940s in American women's sports": "رياضات نسائية أمريكية في عقد 1940",
    "1950s in American women's sports": "رياضات نسائية أمريكية في عقد 1950",
    "1960s in American women's sports": "رياضات نسائية أمريكية في عقد 1960",
    "1970s in American women's sports": "رياضات نسائية أمريكية في عقد 1970",
    "1980s in American women's sports": "رياضات نسائية أمريكية في عقد 1980",
    "1990s in American women's sports": "رياضات نسائية أمريكية في عقد 1990",
    "2010s in American women's sports": "رياضات نسائية أمريكية في عقد 2010",
    "2020s in American women's sports": "رياضات نسائية أمريكية في عقد 2020",
    "Canadian women's sports by year": "رياضات نسائية كندية حسب السنة",
    "Canadian women's sports by decade": "رياضات نسائية كندية حسب العقد",
    "1983 in Canadian women's sports": "رياضات نسائية كندية في 1983",
    "2004 in Canadian women's sports": "رياضات نسائية كندية في 2004",
    "2007 in Canadian women's sports": "رياضات نسائية كندية في 2007",
    "2011 in Canadian women's sports": "رياضات نسائية كندية في 2011",
    "2012 in Canadian women's sports": "رياضات نسائية كندية في 2012",
    "2023 in Canadian women's sports": "رياضات نسائية كندية في 2023",
    "1980s in Canadian women's sports": "رياضات نسائية كندية في عقد 1980",
    "1990s in Canadian women's sports": "رياضات نسائية كندية في عقد 1990",
    "2000s in Canadian women's sports": "رياضات نسائية كندية في عقد 2000",
    "2010s in Canadian women's sports": "رياضات نسائية كندية في عقد 2010",
    "2020s in Canadian women's sports": "رياضات نسائية كندية في عقد 2020",
    "Mexican women's sports by year": "رياضات نسائية مكسيكية حسب السنة",
    "Mexican women's sports by decade": "رياضات نسائية مكسيكية حسب العقد",
    "1971 in Mexican women's sports": "رياضات نسائية مكسيكية في 1971",
    "1974 in Mexican women's sports": "رياضات نسائية مكسيكية في 1974",
    "2010 in Mexican women's sports": "رياضات نسائية مكسيكية في 2010",
    "1970s in Mexican women's sports": "رياضات نسائية مكسيكية في عقد 1970",
    "2010s in Mexican women's sports": "رياضات نسائية مكسيكية في عقد 2010",
}

data3 = {
    "Women's sports by dependent territory": "رياضات نسائية حسب الأقاليم التابعة",
    "Women's sports by populated place": "رياضات نسائية حسب المكان المأهول",
    "Women's sports by sport and country": "رياضات نسائية حسب الرياضة والبلد",
    "Women's sports by year": "رياضات نسائية حسب السنة",
    "Women's sports in American Samoa": "رياضات نسائية في ساموا الأمريكية",
    "Women's sports in Arizona": "رياضات نسائية في أريزونا",
    "Women's sports in Atlanta": "رياضات نسائية في أتلانتا (جورجيا)",
    "Women's sports in Boston": "رياضات نسائية في بوسطن",
    "Women's sports in Botswana": "رياضات نسائية في بوتسوانا",
    "Women's sports in British Columbia": "رياضات نسائية في كولومبيا البريطانية",
    "Women's sports in California": "رياضات نسائية في كاليفورنيا",
    "Women's sports in Canada": "رياضات نسائية في كندا",
    "Women's sports in Charlotte, North Carolina": "رياضات نسائية في تشارلوت (كارولاينا الشمالية)",
    "Women's sports in Chicago": "رياضات نسائية في شيكاغو",
    "Women's sports in Cleveland": "رياضات نسائية في كليفلاند",
    "Women's sports in Connecticut": "رياضات نسائية في كونيتيكت",
    "Women's sports in Dallas": "رياضات نسائية في دالاس",
    "Women's sports in Detroit": "رياضات نسائية في ديترويت",
    "Women's sports in Florida": "رياضات نسائية في فلوريدا",
    "Women's sports in Georgia (U.S. state)": "رياضات نسائية في ولاية جورجيا",
    "Women's sports in Guam": "رياضات نسائية في غوام",
    "Women's sports in Haryana": "رياضات نسائية في هاريانا",
    "Women's sports in Houston": "رياضات نسائية في هيوستن",
    "Women's sports in Illinois": "رياضات نسائية في إلينوي",
    "Women's sports in Indiana": "رياضات نسائية في إنديانا",
    "Women's sports in insular areas of the United States": "رياضات نسائية في المناطق المعزولة في الولايات المتحدة",
    "Women's sports in Iowa": "رياضات نسائية في آيوا",
    "Women's sports in Istanbul": "رياضات نسائية في إسطنبول",
    "Women's sports in Kansas": "رياضات نسائية في كانساس",
    "Women's sports in Kansas City, Missouri": "رياضات نسائية في كانساس سيتي (ميزوري)",
    "Women's sports in Kentucky": "رياضات نسائية في كنتاكي",
    "Women's sports in Lebanon": "رياضات نسائية في لبنان",
    "Women's sports in Los Angeles": "رياضات نسائية في لوس أنجلوس",
    "Women's sports in Louisiana": "رياضات نسائية في لويزيانا",
    "Women's sports in Manitoba": "رياضات نسائية في مانيتوبا",
    "Women's sports in Maryland": "رياضات نسائية في ماريلند",
    "Women's sports in Massachusetts": "رياضات نسائية في ماساتشوستس",
    "Women's sports in Miami": "رياضات نسائية في ميامي",
    "Women's sports in Michigan": "رياضات نسائية في ميشيغان",
    "Women's sports in Minnesota": "رياضات نسائية في منيسوتا",
    "Women's sports in Missouri": "رياضات نسائية في ميزوري",
    "Women's sports in Nevada": "رياضات نسائية في نيفادا",
    "Women's sports in New Jersey": "رياضات نسائية في نيوجيرسي",
    "Women's sports in New York (state)": "رياضات نسائية في ولاية نيويورك",
    "Women's sports in New York City": "رياضات نسائية في مدينة نيويورك",
    "Women's sports in North America": "رياضات نسائية في أمريكا الشمالية",
    "Women's sports in North Carolina": "رياضات نسائية في كارولاينا الشمالية",
    "Women's sports in Nova Scotia": "رياضات نسائية في نوفا سكوشا",
    "Women's sports in Oceania": "رياضات نسائية في أوقيانوسيا",
    "Women's sports in Ohio": "رياضات نسائية في أوهايو",
    "Women's sports in Oklahoma": "رياضات نسائية في أوكلاهوما",
    "Women's sports in Pennsylvania": "رياضات نسائية في بنسلفانيا",
    "Women's sports in Philadelphia": "رياضات نسائية في فيلادلفيا",
    "Women's sports in Puerto Rico": "رياضات نسائية في بورتوريكو",
    "Women's sports in Quebec": "رياضات نسائية في كيبك",
    "Women's sports in Quebec City": "رياضات نسائية في مدينة كيبك",
    "Women's sports in Rhode Island": "رياضات نسائية في رود آيلاند",
    "Women's sports in San Diego": "رياضات نسائية في سان دييغو",
    "Women's sports in Seattle": "رياضات نسائية في سياتل",
    "Women's sports in South Carolina": "رياضات نسائية في كارولاينا الجنوبية",
    "Women's sports in Texas": "رياضات نسائية في تكساس",
    "Women's sports in the Philippines": "رياضات نسائية في الفلبين",
    "Women's sports in the United States": "رياضات نسائية في الولايات المتحدة",
    "Women's sports in Utah": "رياضات نسائية في يوتا",
    "Women's sports in Vancouver": "رياضات نسائية في فانكوفر",
    "Women's sports in West Germany": "رياضات نسائية في ألمانيا الغربية",
    "Women's sports in Wisconsin": "رياضات نسائية في ويسكونسن",
    "1884 in women's sport": "رياضة نسائية في 1884",
    "1885 in women's sport": "رياضة نسائية في 1885",
    "1886 in women's sport": "رياضة نسائية في 1886",
    "1887 in women's sport": "رياضة نسائية في 1887",
    "1888 in women's sport": "رياضة نسائية في 1888",
    "1891 in women's sport": "رياضة نسائية في 1891",
    "1892 in women's sport": "رياضة نسائية في 1892",
    "1893 in women's sport": "رياضة نسائية في 1893",
    "1894 in women's sport": "رياضة نسائية في 1894",
    "1895 in women's sport": "رياضة نسائية في 1895",
    "1896 in women's sport": "رياضة نسائية في 1896",
    "1897 in women's sport": "رياضة نسائية في 1897",
    "1901 in women's sport": "رياضة نسائية في 1901",
    "1902 in women's sport": "رياضة نسائية في 1902",
    "1903 in women's sport": "رياضة نسائية في 1903",
    "1904 in women's sport": "رياضة نسائية في 1904",
    "1905 in women's sport": "رياضة نسائية في 1905",
    "1906 in women's sport": "رياضة نسائية في 1906",
    "1907 in women's sport": "رياضة نسائية في 1907",
    "1908 in women's sport": "رياضة نسائية في 1908",
    "1909 in women's sport": "رياضة نسائية في 1909",
    "1910 in women's sport": "رياضة نسائية في 1910",
    "1911 in women's sport": "رياضة نسائية في 1911",
    "1912 in women's sport": "رياضة نسائية في 1912",
    "1913 in women's sport": "رياضة نسائية في 1913",
    "1914 in women's sport": "رياضة نسائية في 1914",
    "1919 in women's sport": "رياضة نسائية في 1919",
    "1920 in women's sport": "رياضة نسائية في 1920",
    "1921 in women's sport": "رياضة نسائية في 1921",
    "1922 in women's sport": "رياضة نسائية في 1922",
    "1923 in women's sport": "رياضة نسائية في 1923",
    "1924 in women's sport": "رياضة نسائية في 1924",
    "1926 in women's sport": "رياضة نسائية في 1926",
    "1927 in women's sport": "رياضة نسائية في 1927",
    "1928 in women's sport": "رياضة نسائية في 1928",
    "1929 in women's sport": "رياضة نسائية في 1929",
    "1930 in women's sport": "رياضة نسائية في 1930",
    "1932 in women's sport": "رياضة نسائية في 1932",
    "1933 in women's sport": "رياضة نسائية في 1933",
    "1934 in women's sport": "رياضة نسائية في 1934",
    "1936 in women's sport": "رياضة نسائية في 1936",
    "1937 in women's sport": "رياضة نسائية في 1937",
    "1946 in women's sport": "رياضة نسائية في 1946",
    "1947 in women's sport": "رياضة نسائية في 1947",
    "1948 in women's sport": "رياضة نسائية في 1948",
    "1949 in women's sport": "رياضة نسائية في 1949",
    "1950 in women's sport": "رياضة نسائية في 1950",
    "1952 in women's sport": "رياضة نسائية في 1952",
    "1953 in women's sport": "رياضة نسائية في 1953",
    "1954 in women's sport": "رياضة نسائية في 1954",
    "1956 in women's sport": "رياضة نسائية في 1956",
    "1957 in women's sport": "رياضة نسائية في 1957",
    "1959 in women's sport": "رياضة نسائية في 1959",
    "1961 in women's sport": "رياضة نسائية في 1961",
    "1963 in women's sport": "رياضة نسائية في 1963",
    "1964 in women's sport": "رياضة نسائية في 1964",
    "1965 in women's sport": "رياضة نسائية في 1965",
    "1969 in women's sport": "رياضة نسائية في 1969",
    "1970 in women's sport": "رياضة نسائية في 1970",
    "1971 in women's sport": "رياضة نسائية في 1971",
    "1972 in women's sport": "رياضة نسائية في 1972",
    "1973 in women's sport": "رياضة نسائية في 1973",
    "1974 in women's sport": "رياضة نسائية في 1974",
    "1974 in women's sport by country": "رياضة نسائية في 1974 حسب البلد",
    "1975 in women's sport": "رياضة نسائية في 1975",
    "1976 in women's sport": "رياضة نسائية في 1976",
    "1977 in women's sport": "رياضة نسائية في 1977",
    "1978 in women's sport": "رياضة نسائية في 1978",
    "1986 in women's sport by country": "رياضة نسائية في 1986 حسب البلد",
    "1987 in women's sport by country": "رياضة نسائية في 1987 حسب البلد",
    "1988 in women's sport": "رياضة نسائية في 1988",
    "1988 in women's sport by country": "رياضة نسائية في 1988 حسب البلد",
    "1989 in women's sport by country": "رياضة نسائية في 1989 حسب البلد",
    "1990 in women's sport by country": "رياضة نسائية في 1990 حسب البلد",
    "1991 in women's sport by country": "رياضة نسائية في 1991 حسب البلد",
    "1992 in women's sport": "رياضة نسائية في 1992",
    "1992 in women's sport by country": "رياضة نسائية في 1992 حسب البلد",
    "1993 in women's sport by country": "رياضة نسائية في 1993 حسب البلد",
    "1994 in women's sport by country": "رياضة نسائية في 1994 حسب البلد",
    "1995 in women's sport by country": "رياضة نسائية في 1995 حسب البلد",
    "1996 in women's sport by country": "رياضة نسائية في 1996 حسب البلد",
    "1998 in women's sport by country": "رياضة نسائية في 1998 حسب البلد",
    "1999 in women's sport by country": "رياضة نسائية في 1999 حسب البلد",
    "2000 in women's sport by country": "رياضة نسائية في 2000 حسب البلد",
    "2001 in women's sport by country": "رياضة نسائية في 2001 حسب البلد",
    "2003 in women's sport by country": "رياضة نسائية في 2003 حسب البلد",
    "2004 in women's sport by country": "رياضة نسائية في 2004 حسب البلد",
    "2005 in women's sport by country": "رياضة نسائية في 2005 حسب البلد",
    "2006 in women's sport by country": "رياضة نسائية في 2006 حسب البلد",
    "2008 in women's sport by country": "رياضة نسائية في 2008 حسب البلد",
    "2009 in women's sport by country": "رياضة نسائية في 2009 حسب البلد",
    "2010 in women's sport": "رياضة نسائية في 2010",
    "2010 in women's sport by country": "رياضة نسائية في 2010 حسب البلد",
    "2013 in women's sport by country": "رياضة نسائية في 2013 حسب البلد",
    "2014 in women's sport": "رياضة نسائية في 2014",
    "2014 in women's sport by country": "رياضة نسائية في 2014 حسب البلد",
    "2015 in women's sport": "رياضة نسائية في 2015",
    "2015 in women's sport by country": "رياضة نسائية في 2015 حسب البلد",
    "2017 in women's sport by country": "رياضة نسائية في 2017 حسب البلد",
    "2018 in women's sport": "رياضة نسائية في 2018",
    "2018 in women's sport by country": "رياضة نسائية في 2018 حسب البلد",
    "2019 in women's sport by country": "رياضة نسائية في 2019 حسب البلد",
    "Women's sport-related lists": "قوائم متعلقة برياضة نسائية",
    "Women's sport by country and year": "رياضة نسائية حسب البلد والسنة",
    "Women's sport by year and country": "رياضة نسائية حسب السنة والبلد",
    "Women's sport in Afghanistan": "رياضة نسائية في أفغانستان",
    "Women's sport in Albania": "رياضة نسائية في ألبانيا",
    "Women's sport in Algeria": "رياضة نسائية في الجزائر",
    "Women's sport in Amsterdam": "رياضة نسائية في أمستردام",
    "Women's sport in Andorra": "رياضة نسائية في أندورا",
    "Women's sport in Angola": "رياضة نسائية في أنغولا",
    "Women's sport in Antigua and Barbuda": "رياضة نسائية في أنتيغوا وباربودا",
    "Women's sport in Argentina": "رياضة نسائية في الأرجنتين",
    "Women's sport in Armenia": "رياضة نسائية في أرمينيا",
    "Women's sport in Aruba": "رياضة نسائية في أروبا",
    "Women's sport in Australia": "رياضة نسائية في أستراليا",
    "Women's sport in Austria": "رياضة نسائية في النمسا",
    "Women's sport in Azerbaijan": "رياضة نسائية في أذربيجان",
    "Women's sport in Bangladesh": "رياضة نسائية في بنغلاديش",
    "Women's sport in Barbados": "رياضة نسائية في بربادوس",
    "Women's sport in Belarus": "رياضة نسائية في روسيا البيضاء",
    "Women's sport in Belgium": "رياضة نسائية في بلجيكا",
    "Women's sport in Belize": "رياضة نسائية في بليز",
    "Women's sport in Benin": "رياضة نسائية في بنين",
    "Women's sport in Bermuda": "رياضة نسائية في برمودا",
    "Women's sport in Bhutan": "رياضة نسائية في بوتان",
    "Women's sport in Bolivia": "رياضة نسائية في بوليفيا",
    "Women's sport in Bosnia and Herzegovina": "رياضة نسائية في البوسنة والهرسك",
    "Women's sport in Botswana": "رياضة نسائية في بوتسوانا",
    "Women's sport in Brazil": "رياضة نسائية في البرازيل",
    "Women's sport in Brunei": "رياضة نسائية في بروناي",
    "Women's sport in Bulgaria": "رياضة نسائية في بلغاريا",
    "Women's sport in Cambodia": "رياضة نسائية في كمبوديا",
    "Women's sport in Cameroon": "رياضة نسائية في الكاميرون",
    "Women's sport in Central America": "رياضة نسائية في أمريكا الوسطى",
    "Women's sport in Chile": "رياضة نسائية في تشيلي",
    "Women's sport in China": "رياضة نسائية في الصين",
    "Women's sport in Costa Rica": "رياضة نسائية في كوستاريكا",
    "Women's sport in Croatia": "رياضة نسائية في كرواتيا",
    "Women's sport in Cuba": "رياضة نسائية في كوبا",
    "Women's sport in Cyprus": "رياضة نسائية في قبرص",
    "Women's sport in Czechoslovakia": "رياضة نسائية في تشيكوسلوفاكيا",
    "Women's sport in dependent territories of the United Kingdom": "رياضة نسائية في أقاليم ما وراء البحار البريطانية",
    "Women's sport in Djibouti": "رياضة نسائية في جيبوتي",
    "Women's sport in East Germany": "رياضة نسائية في ألمانيا الشرقية",
    "Women's sport in Ecuador": "رياضة نسائية في الإكوادور",
    "Women's sport in Egypt": "رياضة نسائية في مصر",
    "Women's sport in El Salvador": "رياضة نسائية في السلفادور",
    "Women's sport in England": "رياضة نسائية في إنجلترا",
    "Women's sport in Equatorial Guinea": "رياضة نسائية في غينيا الاستوائية",
    "Women's sport in Estonia": "رياضة نسائية في إستونيا",
    "Women's sport in Ethiopia": "رياضة نسائية في إثيوبيا",
    "Women's sport in Fiji": "رياضة نسائية في فيجي",
    "Women's sport in Finland": "رياضة نسائية في فنلندا",
    "Women's sport in France": "رياضة نسائية في فرنسا",
    "Women's sport in French Guiana": "رياضة نسائية في غويانا الفرنسية",
    "Women's sport in Gabon": "رياضة نسائية في الغابون",
    "Women's sport in Georgia (country)": "رياضة نسائية في جورجيا",
    "Women's sport in Germany": "رياضة نسائية في ألمانيا",
    "Women's sport in Ghana": "رياضة نسائية في غانا",
    "Women's sport in Gibraltar": "رياضة نسائية في جبل طارق",
    "Women's sport in Greenland": "رياضة نسائية في جرينلاند",
    "Women's sport in Grenada": "رياضة نسائية في غرينادا",
    "Women's sport in Guadeloupe": "رياضة نسائية في غوادلوب",
    "Women's sport in Guatemala": "رياضة نسائية في غواتيمالا",
    "Women's sport in Guinea": "رياضة نسائية في غينيا",
    "Women's sport in Guyana": "رياضة نسائية في غيانا",
    "Women's sport in Haiti": "رياضة نسائية في هايتي",
    "Women's sport in Hong Kong": "رياضة نسائية في هونغ كونغ",
    "Women's sport in Hungary": "رياضة نسائية في المجر",
    "Women's sport in Iceland": "رياضة نسائية في آيسلندا",
    "Women's sport in India": "رياضة نسائية في الهند",
    "Women's sport in Indonesia": "رياضة نسائية في إندونيسيا",
    "Women's sport in Iran": "رياضة نسائية في إيران",
    "Women's sport in Iraq": "رياضة نسائية في العراق",
    "Women's sport in Ireland": "رياضة نسائية في أيرلندا",
    "Women's sport in Ireland by sport": "رياضة نسائية في أيرلندا حسب الرياضة",
    "Women's sport in Israel": "رياضة نسائية في إسرائيل",
    "Women's sport in Italy": "رياضة نسائية في إيطاليا",
    "Women's sport in Ivory Coast": "رياضة نسائية في ساحل العاج",
    "Women's sport in Jamaica": "رياضة نسائية في جامايكا",
    "Women's sport in Japan": "رياضة نسائية في اليابان",
    "Women's sport in Jordan": "رياضة نسائية في الأردن",
    "Women's sport in Kazakhstan": "رياضة نسائية في كازاخستان",
    "Women's sport in Kenya": "رياضة نسائية في كينيا",
    "Women's sport in Korea": "رياضة نسائية في كوريا",
    "Women's sport in Kosovo": "رياضة نسائية في كوسوفو",
    "Women's sport in Kuwait": "رياضة نسائية في الكويت",
    "Women's sport in Kyrgyzstan": "رياضة نسائية في قيرغيزستان",
    "Women's sport in Laos": "رياضة نسائية في لاوس",
    "Women's sport in Latvia": "رياضة نسائية في لاتفيا",
    "Women's sport in Lebanon": "رياضة نسائية في لبنان",
    "Women's sport in Lesotho": "رياضة نسائية في ليسوتو",
    "Women's sport in Liberia": "رياضة نسائية في ليبيريا",
    "Women's sport in Libya": "رياضة نسائية في ليبيا",
    "Women's sport in Liechtenstein": "رياضة نسائية في ليختنشتاين",
    "Women's sport in Lithuania": "رياضة نسائية في ليتوانيا",
    "Women's sport in London": "رياضة نسائية في لندن",
    "Women's sport in Luxembourg": "رياضة نسائية في لوكسمبورغ",
    "Women's sport in Macau": "رياضة نسائية في ماكاو",
    "Women's sport in Madagascar": "رياضة نسائية في مدغشقر",
    "Women's sport in Malawi": "رياضة نسائية في ملاوي",
    "Women's sport in Malaysia": "رياضة نسائية في ماليزيا",
    "Women's sport in Mali": "رياضة نسائية في مالي",
    "Women's sport in Malta": "رياضة نسائية في مالطا",
    "Women's sport in Mauritius": "رياضة نسائية في موريشيوس",
    "Women's sport in Mexico": "رياضة نسائية في المكسيك",
    "Women's sport in Moldova": "رياضة نسائية في مولدوفا",
    "Women's sport in Monaco": "رياضة نسائية في موناكو",
    "Women's sport in Mongolia": "رياضة نسائية في منغوليا",
    "Women's sport in Montenegro": "رياضة نسائية في الجبل الأسود",
    "Women's sport in Morocco": "رياضة نسائية في المغرب",
    "Women's sport in Mozambique": "رياضة نسائية في موزمبيق",
    "Women's sport in Myanmar": "رياضة نسائية في ميانمار",
    "Women's sport in Namibia": "رياضة نسائية في ناميبيا",
    "Women's sport in Nepal": "رياضة نسائية في نيبال",
    "Women's sport in New Zealand": "رياضة نسائية في نيوزيلندا",
    "Women's sport in Nicaragua": "رياضة نسائية في نيكاراغوا",
    "Women's sport in Niger": "رياضة نسائية في النيجر",
    "Women's sport in Nigeria": "رياضة نسائية في نيجيريا",
    "Women's sport in North Korea": "رياضة نسائية في كوريا الشمالية",
    "Women's sport in North Macedonia": "رياضة نسائية في مقدونيا الشمالية",
    "Women's sport in Northern Ireland": "رياضة نسائية في أيرلندا الشمالية",
    "Women's sport in Norway": "رياضة نسائية في النرويج",
    "Women's sport in Oman": "رياضة نسائية في سلطنة عمان",
    "Women's sport in Pakistan": "رياضة نسائية في باكستان",
    "Women's sport in Palestine": "رياضة نسائية في فلسطين",
    "Women's sport in Panama": "رياضة نسائية في بنما",
    "Women's sport in Papua New Guinea": "رياضة نسائية في بابوا غينيا الجديدة",
    "Women's sport in Paraguay": "رياضة نسائية في باراغواي",
    "Women's sport in Peru": "رياضة نسائية في بيرو",
    "Women's sport in Poland": "رياضة نسائية في بولندا",
    "Women's sport in Portugal": "رياضة نسائية في البرتغال",
    "Women's sport in Qatar": "رياضة نسائية في قطر",
    "Women's sport in Romania": "رياضة نسائية في رومانيا",
    "Women's sport in Russia": "رياضة نسائية في روسيا",
    "Women's sport in Rwanda": "رياضة نسائية في رواندا",
    "Women's sport in Samoa": "رياضة نسائية في ساموا",
    "Women's sport in San Marino": "رياضة نسائية في سان مارينو",
    "Women's sport in Scotland": "رياضة نسائية في إسكتلندا",
    "Women's sport in Senegal": "رياضة نسائية في السنغال",
    "Women's sport in Serbia": "رياضة نسائية في صربيا",
    "Women's sport in Seychelles": "رياضة نسائية في سيشل",
    "Women's sport in Singapore": "رياضة نسائية في سنغافورة",
    "Women's sport in Slovakia": "رياضة نسائية في سلوفاكيا",
    "Women's sport in Slovenia": "رياضة نسائية في سلوفينيا",
    "Women's sport in Somalia": "رياضة نسائية في الصومال",
    "Women's sport in South Africa": "رياضة نسائية في جنوب إفريقيا",
    "Women's sport in South Korea": "رياضة نسائية في كوريا الجنوبية",
    "Women's sport in South Sudan": "رياضة نسائية في جنوب السودان",
    "Women's sport in Southeast Asia": "رياضة نسائية في جنوب شرق آسيا",
    "Women's sport in Spain": "رياضة نسائية في إسبانيا",
    "Women's sport in Sri Lanka": "رياضة نسائية في سريلانكا",
    "Women's sport in Sudan": "رياضة نسائية في السودان",
    "Women's sport in Switzerland": "رياضة نسائية في سويسرا",
    "Women's sport in Syria": "رياضة نسائية في سوريا",
    "Women's sport in Taiwan": "رياضة نسائية في تايوان",
    "Women's sport in Tajikistan": "رياضة نسائية في طاجيكستان",
    "Women's sport in Tanzania": "رياضة نسائية في تنزانيا",
    "Women's sport in Thailand": "رياضة نسائية في تايلاند",
    "Women's sport in the Bahamas": "رياضة نسائية في باهاماس",
    "Women's sport in the Caribbean": "رياضة نسائية في الكاريبي",
    "Women's sport in the Cayman Islands": "رياضة نسائية في جزر كايمان",
    "Women's sport in the Central African Republic": "رياضة نسائية في جمهورية إفريقيا الوسطى",
    "Women's sport in the Comoros": "رياضة نسائية في جزر القمر",
    "Women's sport in the Czech Republic": "رياضة نسائية في التشيك",
    "Women's sport in the Democratic Republic of the Congo": "رياضة نسائية في جمهورية الكونغو الديمقراطية",
    "Women's sport in the Dominican Republic": "رياضة نسائية في جمهورية الدومينيكان",
    "Women's sport in the Faroe Islands": "رياضة نسائية في جزر فارو",
    "Women's sport in the Republic of Ireland": "رياضة نسائية في جمهورية أيرلندا",
    "Women's sport in the Republic of the Congo": "رياضة نسائية في جمهورية الكونغو",
    "Women's sport in the Soviet Union": "رياضة نسائية في الاتحاد السوفيتي",
    "Women's sport in the United Arab Emirates": "رياضة نسائية في الإمارات العربية المتحدة",
    "Women's sport in the United Kingdom": "رياضة نسائية في المملكة المتحدة",
    "Women's sport in Togo": "رياضة نسائية في توغو",
    "Women's sport in Trinidad and Tobago": "رياضة نسائية في ترينيداد وتوباغو",
    "Women's sport in Tunisia": "رياضة نسائية في تونس",
    "Women's sport in Turkey": "رياضة نسائية في تركيا",
    "Women's sport in Turkmenistan": "رياضة نسائية في تركمانستان",
    "Women's sport in Uganda": "رياضة نسائية في أوغندا",
    "Women's sport in Ukraine": "رياضة نسائية في أوكرانيا",
    "Women's sport in Uruguay": "رياضة نسائية في أوروغواي",
    "Women's sport in Uzbekistan": "رياضة نسائية في أوزبكستان",
    "Women's sport in Vanuatu": "رياضة نسائية في فانواتو",
    "Women's sport in Venezuela": "رياضة نسائية في فنزويلا",
    "Women's sport in Vietnam": "رياضة نسائية في فيتنام",
    "Women's sport in Wales": "رياضة نسائية في ويلز",
    "Women's sport in West Germany": "رياضة نسائية في ألمانيا الغربية",
    "Women's sport in Yemen": "رياضة نسائية في اليمن",
    "Women's sport in Yugoslavia": "رياضة نسائية في يوغسلافيا",
    "Women's sport in Zambia": "رياضة نسائية في زامبيا",
    "Women's sport in Zimbabwe": "رياضة نسائية في زيمبابوي",
    "Women's sport navigational boxes": "صناديق تصفح رياضة نسائية",
    "Women's sport templates": "قوالب رياضة نسائية",
    "Women's sports clubs and teams in Afghanistan": "أندية وفرق رياضية نسائية في أفغانستان",
    "Women's sports clubs and teams in Albania": "أندية وفرق رياضية نسائية في ألبانيا",
    "Women's sports clubs and teams in Andorra": "أندية وفرق رياضية نسائية في أندورا",
    "Women's sports clubs and teams in Armenia": "أندية وفرق رياضية نسائية في أرمينيا",
    "Women's sports clubs and teams in Azerbaijan": "أندية وفرق رياضية نسائية في أذربيجان",
    "Women's sports clubs and teams in Bangladesh": "أندية وفرق رياضية نسائية في بنغلاديش",
    "Women's sports clubs and teams in Botswana": "أندية وفرق رياضية نسائية في بوتسوانا",
    "Women's sports clubs and teams in Denmark": "أندية وفرق رياضية نسائية في الدنمارك",
    "Women's sports clubs and teams in Fiji": "أندية وفرق رياضية نسائية في فيجي",
    "Women's sports clubs and teams in Gabon": "أندية وفرق رياضية نسائية في الغابون",
    "Women's sports clubs and teams in Georgia (country)": "أندية وفرق رياضية نسائية في جورجيا",
    "Women's sports clubs and teams in Guatemala": "أندية وفرق رياضية نسائية في غواتيمالا",
    "Women's sports clubs and teams in Guyana": "أندية وفرق رياضية نسائية في غيانا",
    "Women's sports clubs and teams in Haiti": "أندية وفرق رياضية نسائية في هايتي",
    "Women's sports clubs and teams in Hong Kong": "أندية وفرق رياضية نسائية في هونغ كونغ",
    "Women's sports clubs and teams in Ivory Coast": "أندية وفرق رياضية نسائية في ساحل العاج",
    "Women's sports clubs and teams in Kenya": "أندية وفرق رياضية نسائية في كينيا",
    "Women's sports clubs and teams in Kosovo": "أندية وفرق رياضية نسائية في كوسوفو",
    "Women's sports clubs and teams in Laos": "أندية وفرق رياضية نسائية في لاوس",
    "Women's sports clubs and teams in Lebanon": "أندية وفرق رياضية نسائية في لبنان",
    "Women's sports clubs and teams in Lesotho": "أندية وفرق رياضية نسائية في ليسوتو",
    "Women's sports clubs and teams in Malawi": "أندية وفرق رياضية نسائية في ملاوي",
    "Women's sports clubs and teams in Malaysia": "أندية وفرق رياضية نسائية في ماليزيا",
    "Women's sports clubs and teams in Moldova": "أندية وفرق رياضية نسائية في مولدوفا",
    "Women's sports clubs and teams in Montenegro": "أندية وفرق رياضية نسائية في الجبل الأسود",
    "Women's sports clubs and teams in Morocco": "أندية وفرق رياضية نسائية في المغرب",
    "Women's sports clubs and teams in Niger": "أندية وفرق رياضية نسائية في النيجر",
    "Women's sports clubs and teams in Pakistan": "أندية وفرق رياضية نسائية في باكستان",
    "Women's sports clubs and teams in Paraguay": "أندية وفرق رياضية نسائية في باراغواي",
    "Women's sports clubs and teams in Rwanda": "أندية وفرق رياضية نسائية في رواندا",
    "Women's sports clubs and teams in Singapore": "أندية وفرق رياضية نسائية في سنغافورة",
    "Women's sports clubs and teams in Sri Lanka": "أندية وفرق رياضية نسائية في سريلانكا",
    "Women's sports clubs and teams in Syria": "أندية وفرق رياضية نسائية في سوريا",
    "Women's sports clubs and teams in Tajikistan": "أندية وفرق رياضية نسائية في طاجيكستان",
    "Women's sports clubs and teams in the Cayman Islands": "أندية وفرق رياضية نسائية في جزر كايمان",
    "Women's sports clubs and teams in the Central African Republic": "أندية وفرق رياضية نسائية في جمهورية إفريقيا الوسطى",
    "Women's sports clubs and teams in the Dominican Republic": "أندية وفرق رياضية نسائية في جمهورية الدومينيكان",
    "Women's sports clubs and teams in the Philippines": "أندية وفرق رياضية نسائية في الفلبين",
    "Women's sports clubs and teams in Togo": "أندية وفرق رياضية نسائية في توغو",
    "Women's sports clubs and teams in Trinidad and Tobago": "أندية وفرق رياضية نسائية في ترينيداد وتوباغو",
    "Women's sports clubs and teams in Uganda": "أندية وفرق رياضية نسائية في أوغندا",
    "Women's sports clubs and teams in Venezuela": "أندية وفرق رياضية نسائية في فنزويلا",
    "Women's sports clubs and teams in Zambia": "أندية وفرق رياضية نسائية في زامبيا",
    "Women's sports clubs and teams in Zimbabwe": "أندية وفرق رياضية نسائية في زيمبابوي",
    "Women's sports in Indianapolis": "رياضات نسائية في إنديانابوليس",
    "Women's sports in Minneapolis": "رياضات نسائية في مينيابوليس",
    "Women's sports in Oregon": "رياضات نسائية في أوريغن",
    "Women's sports in Palau": "رياضات نسائية في بالاو",
    "Women's sports in Vienna": "رياضات نسائية في فيينا",
}

to_test = [
    ("test_sports_data_1", data1),
    ("test_sports_data_2", data2),
    ("test_sports_data_3", data3),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_sports_data_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
def test_sports_data_2(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
def test_sports_data_3(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)



#!/usr/bin/python3
"""
Resolve country names categories translations

countries_names.py use only countries names without nationalities
countries_names_v2.py use countries names with nationalities

"""

import functools
import logging
from typing import Dict

from ...translations import countries_from_nat
from ...translations_formats import FormatData, MultiDataFormatterBase
from .countries_names_data import formatted_data_en_ar_only

logger = logging.getLogger(__name__)

# NOTE: ONLY_COUNTRY_NAMES should not merge to formatted_data_en_ar_only directly

ONLY_COUNTRY_NAMES = {
    "{en} political leader": "قادة {ar} السياسيون",
    "government ministers of {en}": "وزراء {ar}",
    "secretaries of {en}": "وزراء {ar}",
    "state lieutenant governors of {en}": "نواب حكام الولايات في {ar}",
    "state secretaries of state of {en}": "وزراء خارجية الولايات في {ar}",
}
formatted_data_updated = dict(formatted_data_en_ar_only)
formatted_data_updated.update(ONLY_COUNTRY_NAMES)
countries_from_nat_data: Dict[str, str] = dict(countries_from_nat)

# TODO: COUNTRY_LABEL_OVERRIDES already used in geo_names_formats.py


@functools.lru_cache(maxsize=1)
def _load_bot() -> MultiDataFormatterBase:
    """Load and configure the country names translation bot.

    Creates and configures a FormatData instance that handles the translation
    of country-related category names using formatted data and country name mappings.

    Returns:
        MultiDataFormatterBase: Configured bot instance for country name translation.
    """
    return FormatData(
        formatted_data_updated,
        countries_from_nat_data,
        key_placeholder="{en}",
        value_placeholder="{ar}",
        text_before="the ",
        regex_filter=r"[\w-]",
    )


@functools.lru_cache(maxsize=10000)
def resolve_by_countries_names(category: str) -> str:
    """Resolve a country name category to its Arabic translation.

    Translates English category names that contain country names to their Arabic equivalents
    using the configured translation bot. This function specifically handles categories
    that use country names without nationalities (e.g., "writers from France" rather than "French writers").

    Args:
        category (str): The English category name containing country names to be translated.

    Returns:
        str: The Arabic translation of the category, or an empty string if not found.
    """
    logger.debug(f"<<yellow>> start {category=}")

    nat_bot = _load_bot()
    result = nat_bot.search_all_category(category)

    logger.info(f"<<yellow>> end {category=}, {result=}")
    return result


__all__ = [
    "resolve_by_countries_names",
]



SPORTS_FORMATTED_DATA_NATS_AND_NAMES = {
    "womens {en} open ({en_sport})": "بطولة {ar} المفتوحة {sport_team} للسيدات",
    "{en} open ({en_sport})": "بطولة {ar} المفتوحة {sport_team}",
    "{en} open {en_sport}": "بطولة {ar} المفتوحة {sport_team}",
    "womens {en} open {en_sport}": "بطولة {ar} المفتوحة {sport_team} للسيدات",
}



"""
jobs data
"""

from __future__ import annotations

from typing import Iterable, Mapping

from .jobs_defs import GenderedLabel, GenderedLabelMap, combine_gender_labels


def _build_religious_job_labels(
    religions: Mapping[str, GenderedLabel],
    roles: Mapping[str, GenderedLabel],
) -> GenderedLabelMap:
    """
    Builds a mapping of gendered labels for every valid combination of religion and religious role.

    Parameters:
        religions (Mapping[str, GenderedLabel]): Mapping of religion keys to their gendered labels.
        roles (Mapping[str, GenderedLabel]): Mapping of religious role keys to their gendered labels.

    Returns:
        GenderedLabelMap: A dictionary whose keys are "{religion} {role}" and whose values are gendered label objects with "males" and "females". Entries are created only for pairs where at least one gender label exists; pairs with empty keys or empty label objects are skipped.
    """

    combined_roles: GenderedLabelMap = {}
    for religion_key, religion_labels in religions.items():
        if not religion_key or not religion_labels:
            continue
        for role_key, role_labels in roles.items():
            if not role_key or not role_labels:
                continue
            females_label = combine_gender_labels(role_labels["females"], religion_labels["females"])
            males_label = combine_gender_labels(role_labels["males"], religion_labels["males"])

            if males_label or females_label:
                combined_roles[f"{religion_key} {role_key}"] = {
                    "males": males_label,
                    "females": females_label,
                }

    return combined_roles


def _build_painter_job_labels(
    painter_styles: Mapping[str, GenderedLabel],
    painter_roles: Mapping[str, GenderedLabel],
    painter_categories: Mapping[str, str],
) -> GenderedLabelMap:
    """
    Build gendered label mappings for painter styles, roles, and categories.

    Parameters:
        painter_styles (Mapping[str, GenderedLabel]): Mapping of style keys (e.g., "symbolist") to their gendered Arabic labels.
        painter_roles (Mapping[str, GenderedLabel]): Mapping of role keys to their gendered Arabic labels.
        painter_categories (Mapping[str, str]): Mapping of category keys to human-readable Arabic category labels.

    Returns:
        GenderedLabelMap: Mapping of composite job keys to gendered labels. Keys include base roles, style keys (except "history"), style+role composites (e.g., "symbolist painter"), and category-based entries like "{category} painters" and "{category} artists". Each value is a dict with "males" and "females" Arabic labels.
    """
    # _build_painter_job_labels(PAINTER_STYLES, PAINTER_ROLE_LABELS, PAINTER_CATEGORY_LABELS)
    combined_data: GenderedLabelMap = dict(painter_roles.items())

    combined_data.update({_style: _labels for _style, _labels in painter_styles.items() if _style != "history"})
    for style_key, style_labels in painter_styles.items():
        for role_key, role_labels in painter_roles.items():
            composite_key = f"{style_key} {role_key}"

            males_label = combine_gender_labels(role_labels["males"], style_labels["males"])
            females_label = combine_gender_labels(role_labels["females"], style_labels["females"])

            combined_data[composite_key] = {
                "males": males_label,
                "females": females_label,
            }
    for painter_category, category_label in painter_categories.items():
        if not painter_category or not category_label:
            continue
        combined_data[f"{painter_category} painters"] = {
            "males": f"رسامو {category_label}",
            "females": f"رسامات {category_label}",
        }
        combined_data[f"{painter_category} artists"] = {
            "males": f"فنانو {category_label}",
            "females": f"فنانات {category_label}",
        }

    return combined_data


def _build_military_job_labels(
    military_prefixes: Mapping[str, GenderedLabel],
    military_roles: Mapping[str, GenderedLabel],
    excluded_prefixes: Iterable[str],
) -> GenderedLabelMap:
    """
    Builds a mapping of military job names (including prefix+role composites) to their gendered labels.

    Parameters:
        military_prefixes: Mapping of prefix keys to gendered labels used to modify roles.
        military_roles: Mapping of role keys to base gendered labels.
        excluded_prefixes: Iterable of prefix keys that should not be inserted as standalone keys in the result but will still be used to form composite prefix+role entries.

    Returns:
        GenderedLabelMap: A dictionary whose keys are role names or "prefix role" composites and whose values are gendered label objects with "males" and "females" entries.
    """
    excluded = set(excluded_prefixes)

    combined_roles: GenderedLabelMap = dict(military_roles.items())

    combined_roles.update(
        {
            prefix_key: prefix_labels
            for prefix_key, prefix_labels in military_prefixes.items()
            if prefix_key not in excluded
        }
    )

    for military_key, prefix_labels in military_prefixes.items():
        for role_key, role_labels in military_roles.items():
            composite_key = f"{military_key} {role_key}"
            males_label = combine_gender_labels(role_labels["males"], prefix_labels["males"])
            females_label = combine_gender_labels(role_labels["females"], prefix_labels["females"])
            combined_roles[composite_key] = {
                "males": males_label,
                "females": females_label,
            }

    return combined_roles


__all__ = [
    "_build_religious_job_labels",
    "_build_painter_job_labels",
    "_build_military_job_labels",
]



#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_virginia2_1 = {
    "Baptists from West Virginia": "معمدانيون من فرجينيا الغربية",
    "Defunct private universities and colleges in West Virginia": "جامعات وكليات خاصة سابقة في فرجينيا الغربية",
    "1607 establishments in the Colony of Virginia": "تأسيسات سنة 1607 في مستعمرة فرجينيا",
    "1648 establishments in the Colony of Virginia": "تأسيسات سنة 1648 في مستعمرة فرجينيا",
    "1651 establishments in the Colony of Virginia": "تأسيسات سنة 1651 في مستعمرة فرجينيا",
    "1671 establishments in the Colony of Virginia": "تأسيسات سنة 1671 في مستعمرة فرجينيا",
    "1673 establishments in the Colony of Virginia": "تأسيسات سنة 1673 في مستعمرة فرجينيا",
    "1759 establishments in the Colony of Virginia": "تأسيسات سنة 1759 في مستعمرة فرجينيا",
}

data_virginia2_3 = {
    "Faculty by university or college in Virginia": "هيئة تدريس حسب الجامعة أو الكلية في فرجينيا",
    "Faculty by university or college in West Virginia": "هيئة تدريس حسب الجامعة أو الكلية في فرجينيا الغربية",
    "19th-century West Virginia state court judges": "قضاة محكمة ولاية فرجينيا الغربية في القرن 19",
    "20th-century West Virginia state court judges": "قضاة محكمة ولاية فرجينيا الغربية في القرن 20",
    "21st century in Virginia": "فرجينيا في القرن 21",
    "Adaptations of works by Virginia Woolf": "أعمال مقتبسة عن أعمال فرجينيا وولف",
    "African-American people in West Virginia politics": "أمريكيون أفارقة في سياسة فرجينيا الغربية",
    "Alumni by university or college in Virginia": "خريجون حسب الجامعة أو الكلية في فرجينيا",
    "Architecture in West Virginia": "هندسة معمارية في فرجينيا الغربية",
    "Demographics of Virginia": "التركيبة السكانية في فرجينيا",
    "Education in Williamsburg, Virginia": "التعليم في ويليامزبرغ (فرجينيا)",
    "Jews from West Virginia": "يهود من فرجينيا الغربية",
    "Mayors of Williamsburg, Virginia": "عمدات ويليامزبرغ (فرجينيا)",
    "Musicians from West Virginia by populated place": "موسيقيون من فرجينيا الغربية حسب المكان المأهول",
    "Singer-songwriters from West Virginia": "مغنون وكتاب أغاني من فرجينيا الغربية",
    "Towns in Accomack County, Virginia": "بلدات في مقاطعة أكوماك (فرجينيا)",
    "Towns in Botetourt County, Virginia": "بلدات في مقاطعة بوتيتورت (فرجينيا)",
    "Towns in Brunswick County, Virginia": "بلدات في مقاطعة برونزويك (فرجينيا)",
    "Towns in Franklin County, Virginia": "بلدات في مقاطعة فرانكلين (فرجينيا)",
    "Towns in Grayson County, Virginia": "بلدات في مقاطعة غرايسون (فرجينيا)",
    "Towns in Halifax County, Virginia": "بلدات في مقاطعة هاليفاكس (فرجينيا)",
    "Towns in Loudoun County, Virginia": "بلدات في مقاطعة لودون (فرجينيا)",
    "Towns in Middlesex County, Virginia": "بلدات في مقاطعة ميديلسكس (فرجينيا)",
    "Towns in Southampton County, Virginia": "بلدات في مقاطعة ساوثهامبتون (فرجينيا)",
    "Towns in Tazewell County, Virginia": "بلدات في مقاطعة تازويل (فرجينيا)",
    "Towns in West Virginia": "بلدات في فرجينيا الغربية",
    "Towns in Wythe County, Virginia": "بلدات في مقاطعة وايذ (فرجينيا)",
    "West Virginia Republicans": "أعضاء الحزب الجمهوري في فرجينيا الغربية",
    "Census-designated places in Campbell County, Virginia": "مناطق إحصاء سكاني في مقاطعة كامبل (فرجينيا)",
    "Census-designated places in Henry County, Virginia": "مناطق إحصاء سكاني في مقاطعة هنري (فرجينيا)",
    "Census-designated places in Tazewell County, Virginia": "مناطق إحصاء سكاني في مقاطعة تازويل (فرجينيا)",
    "Geography of Charlottesville, Virginia": "جغرافيا شارلوتسفيل (فرجينيا)",
    "Parks in Charlottesville, Virginia": "متنزهات في شارلوتسفيل (فرجينيا)",
    "Victorian architecture in West Virginia": "عمارة فكتورية في فرجينيا الغربية",
}

data_virginia2_4 = {
    "Democratic Party United States representatives from West Virginia": "أعضاء الحزب الديمقراطي في مجلس النواب الأمريكي من فرجينيا الغربية",
    "Infectious disease deaths in Virginia": "وفيات بأمراض معدية في فرجينيا",
    "Infectious disease deaths in West Virginia": "وفيات بأمراض معدية في فرجينيا الغربية",
    "Metropolitan areas of Virginia": "مناطق فرجينيا الحضرية",
    "Metropolitan areas of West Virginia": "مناطق فرجينيا الغربية الحضرية",
    "Republican Party United States representatives from West Virginia": "أعضاء الحزب الجمهوري في مجلس النواب الأمريكي من فرجينيا الغربية",
    "Unconditional Union Party United States representatives from West Virginia": "أعضاء حزب الاتحاد غير المشروط في مجلس النواب الأمريكي من فرجينيا الغربية",
    "Respiratory disease deaths in West Virginia": "وفيات بأمراض الجهاز التنفسي في فرجينيا الغربية",
    "Eastern Virginia Medical School alumni": "x",
    "University of Virginia School of Medicine alumni": "x",
    "University of Virginia School of Medicine faculty": "x",
    "Virginia Tech alumni": "x",
}

to_test = [
    ("test_virginia2_1", data_virginia2_1),
    ("test_virginia2_3", data_virginia2_3),
    # ("test_virginia2_4", data_virginia2_4),
]


@pytest.mark.parametrize("category, expected", data_virginia2_1.items(), ids=data_virginia2_1.keys())
@pytest.mark.fast
def test_virginia2_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)



"""
Wrapper for legacy category resolvers.
This module coordinates several older resolution strategies to provide
backward compatibility for category translation logic.

Architecture Note:
    The legacy `circular_dependency/` package has been replaced with the new
    `resolvers/` package which provides a clean, non-circular architecture.
    All imports now form a proper DAG (Directed Acyclic Graph).
"""

from __future__ import annotations

import functools
from typing import Callable, Protocol

# Import other legacy resolvers that are not part of the circular dependency
from .legacy_resolvers_bots import event_lab_bot, with_years_bot, year_or_typeo

# Import from the new resolvers package (no circular dependencies)
from .resolvers import event2_d2, initialize_resolvers, translate_general_category_wrap


class Resolver(Protocol):
    """Protocol for resolver functions that convert category names to Arabic labels."""

    def __call__(self, category: str) -> str:
        """
        Resolve a category name to an Arabic label.

        Parameters:
            category: The category name to resolve.

        Returns:
            The Arabic label, or an empty string if no resolution is found.
        """
        ...


# Initialize the resolver callbacks after all modules are loaded
initialize_resolvers()

# Define the resolver pipeline in priority order
# Each resolver is a callable that takes a category string and returns a label or empty string
#
# RESOLVER_PIPELINE: Ordered list of resolver functions
#
# The resolvers are tried in the order listed below. The first resolver to return
# a non-empty string wins. This ordering is significant:
#
# 1. event2_d2 - Country and event-based resolution
# 2. with_years_bot.wrap_try_with_years - Year-based category resolution
# 3. year_or_typeo.label_for_startwith_year_or_typeo - Year prefix patterns and typo handling
# 4. event_lab_bot.event_lab - General event labeling
# 5. translate_general_category_wrap - Catch-all general resolution (lowest priority)
#
# To add a new resolver:
# 1. Import the resolver function at the top of this file
# 2. Insert it into RESOLVER_PIPELINE at the appropriate priority position
# 3. Document its purpose in this docstring
#
# To modify priority:
# 1. Reorder entries in the list
# 2. Update this docstring to reflect the new order

RESOLVER_PIPELINE: list[Callable[[str], str]] = [
    event2_d2,
    with_years_bot.wrap_try_with_years,
    year_or_typeo.label_for_startwith_year_or_typeo,
    event_lab_bot.event_lab,
    translate_general_category_wrap,
]


@functools.lru_cache(maxsize=10000)
def legacy_resolvers(changed_cat: str) -> str:
    """
    Resolve a category label using the legacy resolver chain in priority order.

    This function implements a pipeline pattern, iterating through registered
    resolvers until one returns a non-empty result. The resolvers are tried
    in the order defined in RESOLVER_PIPELINE.

    Parameters:
        changed_cat (str): Category name or identifier to resolve.

    Returns:
        category_label (str): The resolved category label, or an empty string
            if no legacy resolver produces a value.
    """
    for resolver in RESOLVER_PIPELINE:
        category_lab = resolver(changed_cat)
        if category_lab:
            return category_lab

    return ""


__all__ = [
    "legacy_resolvers",
]



#!/usr/bin/python3
""" """

import functools
import logging

from ...translations import SPORT_KEY_RECORDS
from ...translations_formats import FormatDataV2
from .pre_defined import pre_defined_results

logger = logging.getLogger(__name__)

UNIFIED_FORMATTED_DATA: dict[str, str] = {
    "mens a {en_sport}": "{sport_label} للرجال للمحليين",
    "{en_sport} olympics": "{sport_olympic}",
    "{en_sport} olympic": "{sport_olympic}",
    "olympic {en_sport}": "{sport_olympic}",
    "{en_sport} olympic champions": "أبطال {sport_olympic}",
    "{en_sport} mass media": "إعلام {sport_label}",
    # "{en_sport} teams": "فرق {sport_jobs}",
    "{en_sport} teams": "فرق {sport_label}",
    # rugby union tournaments for national teams
    "{en_sport} tournaments for national teams": "بطولات {sport_label} للمنتخبات الوطنية",
    "amateur {en_sport}": "{sport_jobs} للهواة",
    "mens {en_sport}": "{sport_jobs} رجالية",
    "womens {en_sport}": "{sport_jobs} نسائية",
    "youth {en_sport}": "{sport_jobs} شبابية",
    "mens youth {en_sport}": "{sport_jobs} للشباب",
    "womens youth {en_sport}": "{sport_jobs} للشابات",
    "{en_sport} cup playoffs": "تصفيات كأس {sport_jobs}",
    # "{en_sport} cup": "كأس {sport_jobs}",
    "{en_sport} broadcasters": "مذيعو {sport_jobs}",
    "{en_sport} commentators": "معلقو {sport_jobs}",
    "{en_sport} commissioners": "مفوضو {sport_jobs}",
    "{en_sport} trainers": "مدربو {sport_jobs}",
    "{en_sport} coaches": "مدربو {sport_jobs}",
    "{en_sport} managers": "مدربو {sport_jobs}",
    "{en_sport} manager": "مدربو {sport_jobs}",
    "{en_sport} manager history": "تاريخ مدربو {sport_jobs}",
    "{en_sport} footballers": "لاعبو {sport_jobs}",
    "{en_sport} players": "لاعبو {sport_jobs}",
    "{en_sport} fan clubs": "أندية معجبي {sport_jobs}",
    "{en_sport} owners and executives": "رؤساء تنفيذيون وملاك {sport_jobs}",
    "{en_sport} personnel": "أفراد {sport_jobs}",
    "{en_sport} owners": "ملاك {sport_jobs}",
    "{en_sport} executives": "مدراء {sport_jobs}",
    "{en_sport} equipment": "معدات {sport_jobs}",
    "{en_sport} culture": "ثقافة {sport_jobs}",
    "{en_sport} logos": "شعارات {sport_jobs}",
    "{en_sport} tactics and skills": "مهارات {sport_jobs}",
    "{en_sport} media": "إعلام {sport_jobs}",
    "{en_sport} people": "أعلام {sport_jobs}",
    "{en_sport} terminology": "مصطلحات {sport_jobs}",
    "{en_sport} variants": "أشكال {sport_jobs}",
    "{en_sport} governing bodies": "هيئات تنظيم {sport_jobs}",
    "{en_sport} bodies": "هيئات {sport_jobs}",
    "{en_sport} video games": "ألعاب فيديو {sport_jobs}",
    "{en_sport} comics": "قصص مصورة {sport_jobs}",
    "{en_sport} records and statistics": "سجلات وإحصائيات {sport_jobs}",
    "{en_sport} leagues seasons": "مواسم دوريات {sport_jobs}",
    "{en_sport} seasons": "مواسم {sport_jobs}",
    "{en_sport} competition": "منافسات {sport_jobs}",
    "{en_sport} world competitions": "منافسات {sport_jobs} عالمية",
    "{en_sport} television series": "مسلسلات تلفزيونية {sport_jobs}",
    "{en_sport} films": "أفلام {sport_jobs}",
    "{en_sport} music": "موسيقى {sport_jobs}",
    "{en_sport} clubs and teams": "أندية وفرق {sport_jobs}",
    "{en_sport} clubs": "أندية {sport_jobs}",
    "{en_sport} referees": "حكام {sport_jobs}",
    "{en_sport} organizations": "منظمات {sport_jobs}",
    "{en_sport} non-profit organizations": "منظمات غير ربحية {sport_jobs}",
    "{en_sport} non-profit publishers": "ناشرون غير ربحيون {sport_jobs}",
    "{en_sport} stadiums": "ملاعب {sport_jobs}",
    "{en_sport} lists": "قوائم {sport_jobs}",
    "{en_sport} awards": "جوائز {sport_jobs}",
    "{en_sport} songs": "أغاني {sport_jobs}",
    "{en_sport} non-playing staff": "طاقم {sport_jobs} غير اللاعبين",
    "{en_sport} umpires": "حكام {sport_jobs}",
    "{en_sport} results": "نتائج {sport_jobs}",
    "{en_sport} matches": "مباريات {sport_jobs}",
    "{en_sport} rivalries": "دربيات {sport_jobs}",
    # "{en_sport} champions": "أبطال {sport_jobs}",
    "{en_sport} chairmen and investors": "رؤساء ومسيرو {sport_jobs}",
    # "{en_sport}": "{sport_jobs}",
    "defunct indoor {en_sport} cups": "كؤوس {sport_jobs} داخل الصالات سابقة",
    "indoor {en_sport} cups": "كؤوس {sport_jobs} داخل الصالات",
    "outdoor {en_sport} cups": "كؤوس {sport_jobs} في الهواء الطلق",
    "professional {en_sport} cups": "كؤوس {sport_jobs} للمحترفين",
    # NOTE: see test_sport_cup.py
    # "{en_sport} cup": "كؤوس {sport_jobs}",
    # "defunct {en_sport} cup": "كؤوس {sport_jobs} سابقة",
    # "domestic {en_sport} cup": "كؤوس {sport_jobs} محلية",
    "{en_sport} cups": "كؤوس {sport_jobs}",
    "defunct outdoor {en_sport} cups": "كؤوس {sport_jobs} في الهواء الطلق سابقة",
    "defunct {en_sport} cups": "كؤوس {sport_jobs} سابقة",
    "domestic womens {en_sport} cups": "كؤوس {sport_jobs} محلية للسيدات",
    "domestic {en_sport} cups": "كؤوس {sport_jobs} محلية",
    "{en_sport} competitions": "منافسات {sport_jobs}",
    "grand slam ({en_sport}) tournaments": "بطولات {sport_jobs} كبرى",
    "International {en_sport} competitions": "منافسات {sport_jobs} دولية",
    "domestic womens {en_sport} leagues": "دوريات {sport_jobs} محلية للسيدات",
    "domestic {en_sport} leagues": "دوريات {sport_jobs} محلية",
    "indoor {en_sport} leagues": "دوريات {sport_jobs} داخل الصالات",
    "defunct indoor {en_sport} leagues": "دوريات {sport_jobs} داخل الصالات سابقة",
    "professional {en_sport} leagues": "دوريات {sport_jobs} للمحترفين",
    "domestic {en_sport}": "{sport_jobs} محلية",
    "professional {en_sport}": "{sport_jobs} للمحترفين",
    "indoor {en_sport}": "{sport_jobs} داخل الصالات",
    "defunct indoor {en_sport}": "{sport_jobs} داخل الصالات سابقة",
    "domestic womens {en_sport}": "{sport_jobs} محلية للسيدات",
    "under-13 {en_sport}": "{sport_jobs} تحت 13 سنة",
    "under-14 {en_sport}": "{sport_jobs} تحت 14 سنة",
    "under-15 {en_sport}": "{sport_jobs} تحت 15 سنة",
    "under-16 {en_sport}": "{sport_jobs} تحت 16 سنة",
    "under-17 {en_sport}": "{sport_jobs} تحت 17 سنة",
    "under-18 {en_sport}": "{sport_jobs} تحت 18 سنة",
    "under-19 {en_sport}": "{sport_jobs} تحت 19 سنة",
    "under-20 {en_sport}": "{sport_jobs} تحت 20 سنة",
    "under-21 {en_sport}": "{sport_jobs} تحت 21 سنة",
    "under-23 {en_sport}": "{sport_jobs} تحت 23 سنة",
    "under-24 {en_sport}": "{sport_jobs} تحت 24 سنة",
    "college {en_sport}": "{sport_jobs} الكليات",
    "current {en_sport} seasons": "مواسم {sport_jobs} حالية",
    "defunct outdoor {en_sport} leagues": "دوريات {sport_jobs} في الهواء الطلق سابقة",
    "defunct outdoor {en_sport}": "{sport_jobs} في الهواء الطلق سابقة",
    "defunct {en_sport} teams": "فرق {sport_jobs} سابقة",
    "defunct {en_sport}": "{sport_jobs} سابقة",
    "fictional {en_sport}": "{sport_jobs} خيالية",
    "fifth level {en_sport} league": "دوريات {sport_jobs} من الدرجة الخامسة",
    "fifth level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الخامسة",
    "fifth tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الخامسة",
    "fifth tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الخامسة",
    "first level {en_sport} league": "دوريات {sport_jobs} من الدرجة الأولى",
    "first level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الأولى",
    "first tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الأولى",
    "first tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الأولى",
    "first-class {en_sport}": "{sport_jobs} من الدرجة الأولى",
    "first-class {en_sport} teams": "فرق {sport_jobs} من الدرجة الأولى",
    "fourth level {en_sport} league": "دوريات {sport_jobs} من الدرجة الرابعة",
    "fourth level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الرابعة",
    "fourth tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الرابعة",
    "fourth tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الرابعة",
    "grand slam ({en_sport}) tournament champions": "أبطال بطولات {sport_jobs} كبرى",
    "grand slam ({en_sport})": "بطولات {sport_jobs} كبرى",
    "international mens {en_sport} players": "لاعبو {sport_jobs} دوليون",
    "international mens {en_sport}": "{sport_jobs} دولية للرجال",
    "international womens {en_sport} players": "لاعبات {sport_jobs} دوليات",
    "international womens {en_sport}": "{sport_jobs} دولية للسيدات",
    "International {en_sport} competition": "منافسات {sport_jobs} دولية",
    "international {en_sport} managers": "مدربو {sport_jobs} دوليون",
    "international {en_sport} players": "لاعبو {sport_jobs} دوليون",
    "International {en_sport} races": "سباقات {sport_jobs} دولية",
    "International {en_sport}": "{sport_jobs} دولية",
    "international youth {en_sport}": "{sport_jobs} شبابية دولية",
    "mens international {en_sport} players": "لاعبو {sport_jobs} دوليون",
    "mens international {en_sport}": "{sport_jobs} دولية للرجال",
    "mens {en_sport} teams": "فرق {sport_jobs} رجالية",
    "military {en_sport}": "{sport_jobs} عسكرية",
    "multi-national {en_sport} league": "دوريات {sport_jobs} متعددة الجنسيات",
    "national a {en_sport} teams": "منتخبات {sport_jobs} للمحليين",
    "national a. {en_sport} teams": "منتخبات {sport_jobs} للمحليين",
    "national b {en_sport} teams": "منتخبات {sport_jobs} رديفة",
    "national b. {en_sport} teams": "منتخبات {sport_jobs} رديفة",
    "national junior mens {en_sport} teams": "منتخبات {sport_jobs} وطنية للناشئين",
    "national junior {en_sport} teams": "منتخبات {sport_jobs} وطنية للناشئين",
    "national mens {en_sport} teams": "منتخبات {sport_jobs} وطنية رجالية",
    "national reserve {en_sport} teams": "منتخبات {sport_jobs} وطنية احتياطية",
    "national womens {en_sport} teams": "منتخبات {sport_jobs} وطنية نسائية",
    "national {en_sport} champions": "أبطال بطولات {sport_jobs} وطنية",
    "national {en_sport} league": "دوريات {sport_jobs} وطنية",
    "multi-national {en_sport} leagues": "دوريات {sport_jobs} متعددة الجنسيات",
    "defunct national {en_sport} leagues": "دوريات {sport_jobs} وطنية سابقة",
    "national {en_sport} leagues": "دوريات {sport_jobs} وطنية",
    "outdoor {en_sport} leagues": "دوريات {sport_jobs} في الهواء الطلق",
    "defunct national {en_sport} teams": "منتخبات {sport_jobs} وطنية سابقة",
    "national {en_sport} teams": "منتخبات {sport_jobs} وطنية",
    "national {en_sport} team results": "نتائج منتخبات {sport_jobs} وطنية",
    "national youth {en_sport} teams": "منتخبات {sport_jobs} وطنية شبابية",
    "outdoor {en_sport}": "{sport_jobs} في الهواء الطلق",
    "premier {en_sport} league": "دوريات {sport_jobs} من الدرجة الممتازة",
    "premier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الممتازة",
    "reserve {en_sport} teams": "فرق {sport_jobs} احتياطية",
    "second level {en_sport} league": "دوريات {sport_jobs} من الدرجة الثانية",
    "second level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الثانية",
    "second tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الثانية",
    "second tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الثانية",
    "seventh level {en_sport} league": "دوريات {sport_jobs} من الدرجة السابعة",
    "seventh level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة السابعة",
    "seventh tier {en_sport} league": "دوريات {sport_jobs} من الدرجة السابعة",
    "seventh tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة السابعة",
    "sixth level {en_sport} league": "دوريات {sport_jobs} من الدرجة السادسة",
    "sixth level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة السادسة",
    "sixth tier {en_sport} league": "دوريات {sport_jobs} من الدرجة السادسة",
    "sixth tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة السادسة",
    "third level {en_sport} league": "دوريات {sport_jobs} من الدرجة الثالثة",
    "third level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الثالثة",
    "third tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الثالثة",
    "third tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الثالثة",
    "top level {en_sport} league": "دوريات {sport_jobs} من الدرجة الأولى",
    "top level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الأولى",
    "womens international {en_sport} players": "لاعبات {sport_jobs} دوليات",
    "womens international {en_sport}": "{sport_jobs} دولية للسيدات",
    "womens {en_sport} teams": "فرق {sport_jobs} نسائية",
    "{en_sport} league teams": "فرق دوري {sport_jobs}",
    # "{en_sport} league": "دوري {sport_jobs}",
    "{en_sport} leagues": "دوريات {sport_jobs}",
    "defunct {en_sport} leagues": "دوريات {sport_jobs} سابقة",
    "{en_sport} olympic bronze medalists": "ميداليات {sport_jobs} برونزية أولمبية",
    "{en_sport} olympic gold medalists": "ميداليات {sport_jobs} ذهبية أولمبية",
    "{en_sport} olympic silver medalists": "ميداليات {sport_jobs} فضية أولمبية",
    "{en_sport} races": "سباقات {sport_jobs}",
    "{en_sport} super leagues": "دوريات سوبر {sport_jobs}",
    "youth international {en_sport}": "{sport_jobs} دولية شبابية",
    # Category:Multi-national women's basketball leagues in Europe
    "multi-national womens {en_sport} leagues": "دوريات {sport_jobs} نسائية متعددة الجنسيات",
    # Category:National junior women's goalball teams
    "national junior womens {en_sport} teams": "منتخبات {sport_jobs} للناشئات",
    # "national mens {en_sport}": "منتخبات {sport_jobs} وطنية للرجال",
    # "national {en_sport}": "منتخبات {sport_jobs} وطنية",
    # "national womens {en_sport}": "منتخبات {sport_jobs} وطنية للسيدات",
    "national mens {en_sport}": "{sport_jobs} وطنية للرجال",
    "national {en_sport}": "{sport_jobs} وطنية",
    "national womens {en_sport}": "{sport_jobs} وطنية للسيدات",
    # "national under-13 {en_sport}": "منتخبات {sport_jobs} تحت 13 سنة",
    # "national under-14 {en_sport}": "منتخبات {sport_jobs} تحت 14 سنة",
    # "national under-15 {en_sport}": "منتخبات {sport_jobs} تحت 15 سنة",
    # "national under-16 {en_sport}": "منتخبات {sport_jobs} تحت 16 سنة",
    # "national under-17 {en_sport}": "منتخبات {sport_jobs} تحت 17 سنة",
    # "national under-18 {en_sport}": "منتخبات {sport_jobs} تحت 18 سنة",
    # "national under-19 {en_sport}": "منتخبات {sport_jobs} تحت 19 سنة",
    # "national under-20 {en_sport}": "منتخبات {sport_jobs} تحت 20 سنة",
    # "national under-21 {en_sport}": "منتخبات {sport_jobs} تحت 21 سنة",
    # "national under-23 {en_sport}": "منتخبات {sport_jobs} تحت 23 سنة",
    # "national under-24 {en_sport}": "منتخبات {sport_jobs} تحت 24 سنة",
    "national under-13 {en_sport}": "{sport_jobs} تحت 13 سنة",
    "national under-14 {en_sport}": "{sport_jobs} تحت 14 سنة",
    "national under-15 {en_sport}": "{sport_jobs} تحت 15 سنة",
    "national under-16 {en_sport}": "{sport_jobs} تحت 16 سنة",
    "national under-17 {en_sport}": "{sport_jobs} تحت 17 سنة",
    "national under-18 {en_sport}": "{sport_jobs} تحت 18 سنة",
    "national under-19 {en_sport}": "{sport_jobs} تحت 19 سنة",
    "national under-20 {en_sport}": "{sport_jobs} تحت 20 سنة",
    "national under-21 {en_sport}": "{sport_jobs} تحت 21 سنة",
    "national under-23 {en_sport}": "{sport_jobs} تحت 23 سنة",
    "national under-24 {en_sport}": "{sport_jobs} تحت 24 سنة",
    # teams_formatted_data = {
    "amateur {en_sport} world cup": "كأس العالم {sport_team} للهواة",
    "mens {en_sport} world cup": "كأس العالم {sport_team} للرجال",
    "womens {en_sport} world cup": "كأس العالم {sport_team} للسيدات",
    "{en_sport} world cup": "كأس العالم {sport_team}",
    "youth {en_sport} world cup": "كأس العالم {sport_team} للشباب",
    "international {en_sport} council": "المجلس الدولي {sport_team}",
    "mens {en_sport} championship": "بطولة {sport_team} للرجال",
    "mens {en_sport} world championship": "بطولة العالم {sport_team} للرجال",
    "outdoor world {en_sport} championship": "بطولة العالم {sport_team} في الهواء الطلق",
    "womens world {en_sport} championship": "بطولة العالم {sport_team} للسيدات",
    "womens {en_sport} championship": "بطولة {sport_team} للسيدات",
    "womens {en_sport} world championship": "بطولة العالم {sport_team} للسيدات",
    "world amateur {en_sport} championship": "بطولة العالم {sport_team} للهواة",
    "world champion national {en_sport} teams": "أبطال بطولة العالم {sport_team}",
    "world junior {en_sport} championship": "بطولة العالم {sport_team} للناشئين",
    "world outdoor {en_sport} championship": "بطولة العالم {sport_team} في الهواء الطلق",
    "world wheelchair {en_sport} championship": "بطولة العالم {sport_team} على الكراسي المتحركة",
    "world {en_sport} amateur championship": "بطولة العالم {sport_team} للهواة",
    "world {en_sport} championship": "بطولة العالم {sport_team}",
    "world {en_sport} championship competitors": "منافسو بطولة العالم {sport_team}",
    "world {en_sport} championship medalists": "فائزون بميداليات بطولة العالم {sport_team}",
    "world {en_sport} junior championship": "بطولة العالم {sport_team} للناشئين",
    "world {en_sport} youth championship": "بطولة العالم {sport_team} للشباب",
    "world youth {en_sport} championship": "بطولة العالم {sport_team} للشباب",
    "{en_sport} amateur world championship": "بطولة العالم {sport_team} للهواة",
    "{en_sport} junior world championship": "بطولة العالم {sport_team} للناشئين",
    "{en_sport} world amateur championship": "بطولة العالم {sport_team} للهواة",
    "{en_sport} world championship": "بطولة العالم {sport_team}",
    "{en_sport} world junior championship": "بطولة العالم {sport_team} للناشئين",
    "{en_sport} world youth championship": "بطولة العالم {sport_team} للشباب",
    "{en_sport} youth world championship": "بطولة العالم {sport_team} للشباب",
    # world championships in athletics
    "world championship in {en_sport}": "بطولة العالم {sport_team}",
    "world championship in {en_sport} athletes": "عداؤو بطولة العالم {sport_team}",
    # labels_formatted_data = {
    "{en_sport} finals": "نهائيات {sport_label}",
    "{en_sport}": "{sport_label}",
    "{en_sport} cup": "كأس {sport_label}",
    "olympic gold medalists in {en_sport}": "فائزون بميداليات ذهبية أولمبية في {sport_label}",
    "olympic silver medalists in {en_sport}": "فائزون بميداليات فضية أولمبية في {sport_label}",
    "olympic bronze medalists in {en_sport}": "فائزون بميداليات برونزية أولمبية في {sport_label}",
    "{en_sport} league": "دوري {sport_label}",
    "{en_sport} champions": "أبطال {sport_label}",
    "olympics {en_sport}": "{sport_label} في الألعاب الأولمبية",
    "summer olympics {en_sport}": "{sport_label} في الألعاب الأولمبية الصيفية",
    "winter olympics {en_sport}": "{sport_label} في الألعاب الأولمبية الشتوية",
    # spicial cases
    "olympics sports": "رياضات الألعاب الأولمبية",
    "summer olympics sports": "رياضات الألعاب الأولمبية الصيفية",
    "winter olympics sports": "رياضات الألعاب الأولمبية الشتوية",
    "rugby union chairmen and investors": "رؤساء ومسيرو اتحاد الرجبي",
    "rugby league chairmen and investors": "رؤساء ومسيرو دوري الرجبي",
    "multi-national {en_sport} championships": "بطولات {sport_jobs} متعددة الجنسيات",
    "national {en_sport} championships": "بطولات {sport_jobs} وطنية",
    "{en_sport} championships": "بطولات {sport_jobs}",
    "amateur {en_sport} championships": "بطولات {sport_jobs} للهواة",
}


@functools.lru_cache(maxsize=1)
def _build_unified_sport_keys() -> dict[str, dict[str, str]]:
    """
    Build a unified dictionary mapping sport names to their translation values.

    Returns:
        dict[str, dict[str, str]]: Dictionary where keys are sport names and values
        are dicts containing 'sport_jobs', 'sport_team', and 'sport_label' keys.
    """
    unified: dict[str, dict[str, str]] = {}

    for sport, record in SPORT_KEY_RECORDS.items():
        sport_lower = sport.lower()
        unified[sport_lower] = {
            "sport_jobs": record.get("jobs", ""),
            "sport_team": record.get("team", ""),
            "sport_label": record.get("label", ""),
            "sport_olympic": record.get("olympic", ""),
        }
    unified.update(
        {
            "sports": {
                "sport_jobs": "رياضية",
                "sport_team": "",
                "sport_label": "رياضات",
            }
        }
    )
    return unified


@functools.lru_cache(maxsize=1)
def _load_unified_bot() -> FormatDataV2:
    """
    Create and cache the unified FormatDataV2 instance.

    Returns:
        FormatDataV2: Configured bot for all sports translations.
    """

    UNIFIED_SPORT_KEYS: dict[str, dict[str, str]] = _build_unified_sport_keys()

    return FormatDataV2(
        formatted_data=UNIFIED_FORMATTED_DATA,
        data_list=UNIFIED_SPORT_KEYS,
        key_placeholder="{en_sport}",
    )


def fix_result_callable(result: str, category: str, key: str, value: str) -> str:
    if result.startswith("لاعبو ") and "للسيدات" in result:
        result = result.replace("لاعبو ", "لاعبات ")

    if key == "teams" and "national" in category:
        result = result.replace("فرق ", "منتخبات ")

    return result


@functools.lru_cache(maxsize=10000)
def fix_keys(category: str) -> str:
    """
    Normalize a raw category string by removing quotes and prefixes, fixing common typos, and trimming whitespace.

    Parameters:
        category (str): Input category text that may contain single quotes, a "category:" prefix, inconsistent casing, or the typo "playerss".

    Returns:
        str: The cleaned category string in lowercase with the "category:" prefix and single quotes removed, "playerss" corrected to "players", and surrounding whitespace trimmed.
    """
    category = category.replace("'", "").lower().replace("category:", "")
    category = category.replace("playerss", "players")
    return category.strip()


@functools.lru_cache(maxsize=10000)
def resolve_sport_label_unified(category: str, default: str = "") -> str:
    """
    Resolve the Arabic label for a sport given a category key.

    Normalizes the provided category and attempts to find a matching Arabic sport label; returns the provided default when no match is found.


    This function combines the functionality of:
    - resolve_sport_label_unified
    - resolve_sport_label_by_teams_key
    - resolve_sport_label_by_labels_key

    Parameters:
        category (str): Category key or phrase identifying the sport to resolve.
        default (str): Value to return if no label can be found.

    Returns:
        str: The resolved Arabic sport label if found, otherwise `default`.
    """
    logger.debug(f"<<yellow>> start {category=}")
    category = fix_keys(category)

    # if pre_defined_results.get(category):
    # logger.info(f"<<yellow>> end (pre_defined): {category=}, {pre_defined_results[category]=}")
    #     return pre_defined_results[category]

    if SPORT_KEY_RECORDS.get(category):
        label = SPORT_KEY_RECORDS[category].get("label", "")
        logger.info(f"<<yellow>> end (SPORT_KEY_RECORDS): {category=}, {label=}")
        return label

    unified_bot = _load_unified_bot()
    result = unified_bot.search(category)

    if not result and "world" in category:
        category2 = category.replace("championships", "championship")
        result = unified_bot.search(category2)

    logger.info(f"<<yellow>> end {category=}, {result=}")
    return result or default


__all__ = [
    "resolve_sport_label_unified",
]



#
import pytest

from ArWikiCats import resolve_label_ar

data = {
    "Bridges in Wales by type": "جسور في ويلز حسب الفئة",
    "British Rail": "السكك الحديدية البريطانية",
    "History of British Rail": "تاريخ السكك الحديدية البريطانية",
    "design companies disestablished in 1905": "شركات تصميم انحلت في 1905",
    "landmarks in Yemen": "معالم في اليمن",
    "parks in the Roman Empire": "متنزهات في الإمبراطورية الرومانية",
    "Airlines established in 1968": "شركات طيران أسست في 1968",
    "Airlines of Afghanistan": "شركات طيران في أفغانستان",
    "Cargo airlines of the Philippines": "شحن جوي في الفلبين",
    "Vehicle manufacturing companies disestablished in 1904": "شركات تصنيع المركبات انحلت في 1904",
}


@pytest.mark.parametrize("category, expected", data.items(), ids=data.keys())
@pytest.mark.fast
def test_places_and_structures(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected



#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_0 = {
    "American science and technology awards": "",
    "Appropriate technology": "",
    "Assistive technology": "",
    "Banking technology": "",
    "British science and technology awards": "",
    "Building technology": "",
    "Canadian science and technology awards": "",
    "Cleanroom technology": "",
    "Digital technology": "",
    "Display technology": "",
    "Display technology companies": "",
    "DNA nanotechnology": "",
    "Drilling technology": "",
    "Dutch science and technology awards": "",
    "Electronic paper technology": "",
    "European Union technology policy": "",
    "Fiction about nanotechnology": "",
    "Fictional technology": "",
    "Film and video technology templates": "",
    "Financial technology": "",
    "Flavor technology": "",
    "Food technology": "",
    "French science and technology awards": "",
    "German science and technology awards": "",
    "High-technology business districts": "",
    "Hypothetical technology": "",
    "Indian science and technology awards": "",
    "Information technology companies": "",
    "Information technology companies by country": "",
    "Information technology places": "",
    "Internet technology companies": "",
    "Missile technology": "",
    "Nanotechnology": "",
    "Nanotechnology and the environment": "",
    "Nanotechnology companies": "",
    "Nanotechnology templates": "",
    "Neurotechnology": "",
    "Nuclear technology companies of the United States": "",
    "Nuclear technology organizations of Japan": "",
    "Power station technology": "",
    "Radio technology templates": "",
    "Russian science and technology awards": "",
    "Science, technology, and engineering WikiProjects": "",
    "Science and technology in Prayagraj": "",
    "Sound production technology": "",
    "Sound recording technology": "",
    "Swedish science and technology awards": "",
    "Travel technology": "",
    "Waste treatment technology": "",
    "Water technology": "",
    "Web technology": "",
}

data_fast = {
    "American technology journalists": "صحفيو تقانة أمريكيون",
    "American technology writers": "كتاب تقانة أمريكيون",
    "Australian technology writers": "كتاب تقانة أستراليون",
    "Austrian technology writers": "كتاب تقانة نمساويون",
    "British technology journalists": "صحفيو تقانة بريطانيون",
    "Chinese technology writers": "كتاب تقانة صينيون",
    "Environmental technology": "تقانة بيئية",
    "Films by technology": "أفلام حسب التقانة",
    "French technology writers": "كتاب تقانة فرنسيون",
    "Greek technology writers": "كتاب تقانة يونانيون",
    "Information technology by country": "تقانة المعلومات حسب البلد",
    "Information technology companies of Africa": "شركات تقانة المعلومات في إفريقيا",
    "Information technology companies of Africa by country": "شركات تقانة المعلومات في إفريقيا حسب البلد",
    "Information technology companies of Australia": "شركات تقانة المعلومات في أستراليا",
    "Information technology companies of Egypt": "شركات تقانة المعلومات في مصر",
    "Information technology companies of France": "شركات تقانة المعلومات في فرنسا",
    "Information technology companies of India": "شركات تقانة المعلومات في الهند",
    "Information technology companies of Japan": "شركات تقانة المعلومات في اليابان",
    "Information technology companies of Russia": "شركات تقانة المعلومات في روسيا",
    "Information technology companies of South Korea": "شركات تقانة المعلومات في كوريا الجنوبية",
    "Information technology companies of the United States": "شركات تقانة المعلومات في الولايات المتحدة",
    "Information technology in Australia": "تقانة المعلومات في أستراليا",
    "Information technology in Brazil": "تقانة المعلومات في البرازيل",
    "Information technology in Bulgaria": "تقانة المعلومات في بلغاريا",
    "Information technology in Canada": "تقانة المعلومات في كندا",
    "Information technology in Chile": "تقانة المعلومات في تشيلي",
    "Information technology in China": "تقانة المعلومات في الصين",
    "Information technology in Denmark": "تقانة المعلومات في الدنمارك",
    "Information technology in France": "تقانة المعلومات في فرنسا",
    "Information technology in Germany": "تقانة المعلومات في ألمانيا",
    "Information technology in India": "تقانة المعلومات في الهند",
    "Information technology in Israel": "تقانة المعلومات في إسرائيل",
    "Information technology in Japan": "تقانة المعلومات في اليابان",
    "Information technology in Kazakhstan": "تقانة المعلومات في كازاخستان",
    "Information technology in Mali": "تقانة المعلومات في مالي",
    "Information technology in Mauritius": "تقانة المعلومات في موريشيوس",
    "Information technology in Mexico": "تقانة المعلومات في المكسيك",
    "Information technology in New Zealand": "تقانة المعلومات في نيوزيلندا",
    "Information technology in Nigeria": "تقانة المعلومات في نيجيريا",
    "Information technology in North Korea": "تقانة المعلومات في كوريا الشمالية",
    "Information technology in Norway": "تقانة المعلومات في النرويج",
    "Information technology in Pakistan": "تقانة المعلومات في باكستان",
    "Information technology in Russia": "تقانة المعلومات في روسيا",
    "Information technology in South Korea": "تقانة المعلومات في كوريا الجنوبية",
    "Information technology in Sri Lanka": "تقانة المعلومات في سريلانكا",
    "Information technology in Sweden": "تقانة المعلومات في السويد",
    "Information technology in Switzerland": "تقانة المعلومات في سويسرا",
    "Information technology in Syria": "تقانة المعلومات في سوريا",
    "Information technology in Thailand": "تقانة المعلومات في تايلاند",
    "Information technology in the Netherlands": "تقانة المعلومات في هولندا",
    "Information technology in the Philippines": "تقانة المعلومات في الفلبين",
    "Information technology in the United Arab Emirates": "تقانة المعلومات في الإمارات العربية المتحدة",
    "Information technology in the United Kingdom": "تقانة المعلومات في المملكة المتحدة",
    "Information technology in the United States": "تقانة المعلومات في الولايات المتحدة",
    "Information technology in Tokelau": "تقانة المعلومات في توكيلاو",
    "Information technology in Ukraine": "تقانة المعلومات في أوكرانيا",
    "Irish technology writers": "كتاب تقانة أيرلنديون",
    "Military technology": "تقانة عسكرية",
    "Non-profit technology": "تقانة العمل الخيري",
    "Nuclear technology in Argentina": "تقانة نووية في الأرجنتين",
    "Nuclear technology in Australia": "تقانة نووية في أستراليا",
    "Nuclear technology in Austria": "تقانة نووية في النمسا",
    "Nuclear technology in Brazil": "تقانة نووية في البرازيل",
    "Nuclear technology in China": "تقانة نووية في الصين",
    "Nuclear technology in Denmark": "تقانة نووية في الدنمارك",
    "Nuclear technology in Egypt": "تقانة نووية في مصر",
    "Nuclear technology in Finland": "تقانة نووية في فنلندا",
    "Nuclear technology in France": "تقانة نووية في فرنسا",
    "Nuclear technology in Germany": "تقانة نووية في ألمانيا",
    "Nuclear technology in India": "تقانة نووية في الهند",
    "Nuclear technology in Iran": "تقانة نووية في إيران",
    "Nuclear technology in Iraq": "تقانة نووية في العراق",
    "Nuclear technology in Israel": "تقانة نووية في إسرائيل",
    "Nuclear technology in Italy": "تقانة نووية في إيطاليا",
    "Nuclear technology in Japan": "تقانة نووية في اليابان",
    "Nuclear technology in Jordan": "تقانة نووية في الأردن",
    "Nuclear technology in Libya": "تقانة نووية في ليبيا",
    "Nuclear technology in New Zealand": "تقانة نووية في نيوزيلندا",
    "Nuclear technology in North Korea": "تقانة نووية في كوريا الشمالية",
    "Nuclear technology in Pakistan": "تقانة نووية في باكستان",
    "Nuclear technology in Saudi Arabia": "تقانة نووية في السعودية",
    "Nuclear technology in South Korea": "تقانة نووية في كوريا الجنوبية",
    "Nuclear technology in Sweden": "تقانة نووية في السويد",
    "Nuclear technology in Taiwan": "تقانة نووية في تايوان",
    "Nuclear technology in Thailand": "تقانة نووية في تايلاند",
    "Nuclear technology in the Czech Republic": "تقانة نووية في التشيك",
    "Nuclear technology in the Netherlands": "تقانة نووية في هولندا",
    "Nuclear technology in the United Kingdom": "تقانة نووية في المملكة المتحدة",
    "Nuclear technology in the United States": "تقانة نووية في الولايات المتحدة",
    "Nuclear technology in Turkey": "تقانة نووية في تركيا",
    "Nuclear technology in Ukraine": "تقانة نووية في أوكرانيا",
    "Nuclear technology organizations by country": "منظمات تقانة نووية حسب البلد",
    "Pakistani technology writers": "كتاب تقانة باكستانيون",
    "People in information technology": "أشخاص في تقانة المعلومات",
    "Stealth technology": "تقانة التخفي",
    "Video games about nuclear technology": "ألعاب فيديو عن تقانة نووية",
    "Women technology writers": "كاتبات تقانة",
    "Works about technology": "أعمال عن التقانة",
}

data_slow = {
    "Aviation technology": "تقانة طيران",
    "Businesspeople in information technology": "شخصيات أعمال في تقانة المعلومات",
    "Businesspeople in technology": "شخصيات أعمال في التقانة",
    "Defunct technology companies": "شركات تقانة سابقة",
    "Defunct technology companies of the United Kingdom": "شركات تقانة سابقة في المملكة المتحدة",
    "Documentary films about technology": "أفلام وثائقية عن التقانة",
    "Historians of technology": "مؤرخو التقانة",
    "History of science and technology in China": "تاريخ العلوم والتقانة في الصين",
    "History of science and technology in England": "تاريخ العلوم والتقانة في إنجلترا",
    "Information technology in Uruguay": "تقانة المعلومات في أوروغواي",
    "Music technology": "تقانة موسيقية",
    "Nuclear technology by former country": "تقانة نووية حسب البلد السابق",
    "Nuclear technology in Kazakhstan": "تقانة نووية في كازاخستان",
    "Nuclear technology in Russia": "تقانة نووية في روسيا",
    "Nuclear technology in the Soviet Union": "تقانة نووية في الاتحاد السوفيتي",
    "People associated with technology": "أشخاص مرتبطون مع التقانة",
    "Philosophers of technology": "فلاسفة من التقانة",
    "Politics and technology": "السياسة والتقانة",
    "Science and technology by continent": "العلوم والتقانة حسب القارة",
    "Science and technology by country": "العلوم والتقانة حسب البلد",
    "Science and technology by location": "العلوم والتقانة حسب الموقع",
    "Science and technology in Algeria": "العلوم والتقانة في الجزائر",
    "Science and technology in Asia": "العلوم والتقانة في آسيا",
    "Science and technology in Australia": "العلوم والتقانة في أستراليا",
    "Science and technology in Australia by state or territory": "العلوم والتقانة في أستراليا حسب الولاية أو الإقليم",
    "Science and technology in Austria": "العلوم والتقانة في النمسا",
    "Science and technology in Azerbaijan": "العلوم والتقانة في أذربيجان",
    "Science and technology in Bahrain": "العلوم والتقانة في البحرين",
    "Science and technology in Bosnia and Herzegovina": "العلوم والتقانة في البوسنة والهرسك",
    "Science and technology in Brazil": "العلوم والتقانة في البرازيل",
    "Science and technology in California": "العلوم والتقانة في كاليفورنيا",
    "Science and technology in Cambridgeshire": "العلوم والتقانة في كامبريدجشير",
    "Science and technology in Canada": "العلوم والتقانة في كندا",
    "Science and technology in China": "العلوم والتقانة في الصين",
    "Science and technology in Colombia": "العلوم والتقانة في كولومبيا",
    "Science and technology in Denmark": "العلوم والتقانة في الدنمارك",
    "Science and technology in Devon": "العلوم والتقانة في ديفون",
    "Science and technology in East Asia": "العلوم والتقانة في شرق آسيا",
    "Science and technology in Egypt": "العلوم والتقانة في مصر",
    "Science and technology in El Salvador": "العلوم والتقانة في السلفادور",
    "Science and technology in England": "العلوم والتقانة في إنجلترا",
    "Science and technology in Essex": "العلوم والتقانة في إسكس",
    "Science and technology in Estonia": "العلوم والتقانة في إستونيا",
    "Science and technology in Finland": "العلوم والتقانة في فنلندا",
    "Science and technology in France": "العلوم والتقانة في فرنسا",
    "Science and technology in Germany": "العلوم والتقانة في ألمانيا",
    "Science and technology in Greater Manchester": "العلوم والتقانة في مانشستر الكبرى",
    "Science and technology in Hampshire": "العلوم والتقانة في هامبشاير",
    "Science and technology in Hertfordshire": "العلوم والتقانة في هيرتفوردشاير",
    "Science and technology in India": "العلوم والتقانة في الهند",
    "Science and technology in Iran": "العلوم والتقانة في إيران",
    "Science and technology in Iraq": "العلوم والتقانة في العراق",
    "Science and technology in Israel": "العلوم والتقانة في إسرائيل",
    "Science and technology in Italy": "العلوم والتقانة في إيطاليا",
    "Science and technology in Japan": "العلوم والتقانة في اليابان",
    "Science and technology in Jordan": "العلوم والتقانة في الأردن",
    "Science and technology in Korea": "العلوم والتقانة في كوريا",
    "Science and technology in Kuwait": "العلوم والتقانة في الكويت",
    "Science and technology in Lebanon": "العلوم والتقانة في لبنان",
    "Science and technology in Leicestershire": "العلوم والتقانة في ليسترشير",
    "Science and technology in London": "العلوم والتقانة في لندن",
    "Science and technology in Merseyside": "العلوم والتقانة في مرزيسايد",
    "Science and technology in Morocco": "العلوم والتقانة في المغرب",
    "Science and technology in New South Wales": "العلوم والتقانة في نيوساوث ويلز",
    "Science and technology in New York (state)": "العلوم والتقانة في ولاية نيويورك",
    "Science and technology in North America": "العلوم والتقانة في أمريكا الشمالية",
    "Science and technology in North Korea": "العلوم والتقانة في كوريا الشمالية",
    "Science and technology in Norway": "العلوم والتقانة في النرويج",
    "Science and technology in Oceania": "العلوم والتقانة في أوقيانوسيا",
    "Science and technology in Oxfordshire": "العلوم والتقانة في أوكسفوردشاير",
    "Science and technology in Pakistan": "العلوم والتقانة في باكستان",
    "Science and technology in Palestine": "العلوم والتقانة في فلسطين",
    "Science and technology in Poland": "العلوم والتقانة في بولندا",
    "Science and technology in Qatar": "العلوم والتقانة في قطر",
    "Science and technology in Russia": "العلوم والتقانة في روسيا",
    "Science and technology in Saudi Arabia": "العلوم والتقانة في السعودية",
    "Science and technology in Scotland": "العلوم والتقانة في إسكتلندا",
    "Science and technology in Sierra Leone": "العلوم والتقانة في سيراليون",
    "Science and technology in Slovenia": "العلوم والتقانة في سلوفينيا",
    "Science and technology in Somerset": "العلوم والتقانة في سومرست",
    "Science and technology in South America": "العلوم والتقانة في أمريكا الجنوبية",
    "Science and technology in South Korea": "العلوم والتقانة في كوريا الجنوبية",
    "Science and technology in Spain": "العلوم والتقانة في إسبانيا",
    "Science and technology in Sudan": "العلوم والتقانة في السودان",
    "Science and technology in Sweden": "العلوم والتقانة في السويد",
    "Science and technology in Switzerland": "العلوم والتقانة في سويسرا",
    "Science and technology in Syria": "العلوم والتقانة في سوريا",
    "Science and technology in the Caribbean": "العلوم والتقانة في الكاريبي",
    "Science and technology in the East Riding of Yorkshire": "العلوم والتقانة في إيست رايدينج أوف يوركشير",
    "Science and technology in the Netherlands": "العلوم والتقانة في هولندا",
    "Science and technology in the Ottoman Empire": "العلوم والتقانة في الدولة العثمانية",
    "Science and technology in the San Francisco Bay Area": "العلوم والتقانة في منطقة خليج سان فرانسيسكو",
    "Science and technology in the Soviet Union": "العلوم والتقانة في الاتحاد السوفيتي",
    "Science and technology in the United Arab Emirates": "العلوم والتقانة في الإمارات العربية المتحدة",
    "Science and technology in the United Kingdom": "العلوم والتقانة في المملكة المتحدة",
    "Science and technology in the United States": "العلوم والتقانة في الولايات المتحدة",
    "Science and technology in the United States by state or territory": "العلوم والتقانة في الولايات المتحدة حسب الولاية أو الإقليم",
    "Science and technology in the West Midlands (county)": "العلوم والتقانة في مقاطعة ميدلاند الغربية",
    "Science and technology in Tunisia": "العلوم والتقانة في تونس",
    "Science and technology in Uruguay": "العلوم والتقانة في أوروغواي",
    "Science and technology in Wales": "العلوم والتقانة في ويلز",
    "Science and technology in Warwickshire": "العلوم والتقانة في وركشير",
    "Science and technology in West Sussex": "العلوم والتقانة في غرب ساسكس",
    "Science and technology in West Yorkshire": "العلوم والتقانة في غرب يوركشاير",
    "Science and technology in Yemen": "العلوم والتقانة في اليمن",
    "Sports technology": "تقانة رياضية",
}

to_test = [
    ("test_technology_1", data_fast),
    ("test_technology_slow", data_slow),
]


@pytest.mark.parametrize("category, expected", data_fast.items(), ids=data_fast.keys())
@pytest.mark.fast
def test_technology_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data_slow.items(), ids=data_slow.keys())
@pytest.mark.slow
def test_technology_slow(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)



#!/usr/bin/python3
"""
Build lookup tables for translating sport related keys.
"""

from typing import Final, Mapping

from ..data_builders.build_sport_keys import (
    SportKeyRecord,
    SportKeyTables,
    _build_tables,
    _generate_variants,
    _initialise_tables,
)
from ..helps import len_print
from ..utils import open_json_file

ALIASES: Final[Mapping[str, str]] = {
    "kick boxing": "kickboxing",
    "sport climbing": "climbing",
    "aquatic sports": "aquatics",
    "shooting": "shooting sport",
    "motorsports": "motorsport",
    "road race": "road cycling",
    "cycling road race": "road cycling",
    "road bicycle racing": "road cycling",
    "auto racing": "automobile racing",
    "bmx racing": "bmx",
    "equestrianism": "equestrian",
    "mountain bike racing": "mountain bike",
}


data = open_json_file("sports/Sports_Keys_New.json") or {}
SPORT_KEY_RECORDS_BASE: dict[str, SportKeyRecord] = _initialise_tables(data, ALIASES)
# Variants are created in a separate dictionary to avoid modifying the
# collection while iterating over it.
SPORT_KEY_RECORDS_VARIANTS = _generate_variants(SPORT_KEY_RECORDS_BASE)

SPORT_KEY_RECORDS = SPORT_KEY_RECORDS_BASE | SPORT_KEY_RECORDS_VARIANTS

SPORT_KEY_TABLES: SportKeyTables = _build_tables(SPORT_KEY_RECORDS)

SPORTS_KEYS_FOR_TEAM: Final[dict[str, str]] = SPORT_KEY_TABLES.team
SPORTS_KEYS_FOR_LABEL: Final[dict[str, str]] = SPORT_KEY_TABLES.label
# SPORTS_KEYS_FOR_LABEL["sports"] = "رياضات"
# SPORTS_KEYS_FOR_LABEL["sports"] = "ألعاب رياضية"

SPORTS_KEYS_FOR_JOBS: Final[dict[str, str]] = SPORT_KEY_TABLES.jobs
SPORTS_KEYS_FOR_JOBS["sports"] = "رياضية"

len_print.data_len(
    "Sport_key.py",
    {
        "SPORT_KEY_RECORDS": SPORT_KEY_RECORDS,
        "SPORT_KEY_RECORDS_BASE": SPORT_KEY_RECORDS_BASE,
        "SPORT_KEY_RECORDS_VARIANTS": SPORT_KEY_RECORDS_VARIANTS,
        "SPORTS_KEYS_FOR_LABEL": SPORTS_KEYS_FOR_LABEL,
        "SPORTS_KEYS_FOR_JOBS": SPORTS_KEYS_FOR_JOBS,
        "SPORTS_KEYS_FOR_TEAM": SPORTS_KEYS_FOR_TEAM,
    },
)

__all__ = [
    "SPORT_KEY_RECORDS",
    "SPORT_KEY_RECORDS_BASE",
    "SPORT_KEY_RECORDS_VARIANTS",
    "SPORT_KEY_TABLES",
    "SPORTS_KEYS_FOR_LABEL",
    "SPORTS_KEYS_FOR_JOBS",
    "SPORTS_KEYS_FOR_TEAM",
]



"""
Tests
"""

import pytest

from ArWikiCats import resolve_label_ar

fast_data_drama = {
    "2010 in animation": "رسوم متحركة في 2010",
    "Non-fiction works about the United States Army": "أعمال غير خيالية عن القوات المسلحة الأمريكية",
    "lists of non-fiction works": "قوائم أعمال غير خيالية",
    "non-fiction works about crime in canada": "أعمال غير خيالية عن جريمة في كندا",
    "non-fiction works about espionage": "أعمال غير خيالية عن التجسس",
    "non-fiction works about law in canada": "أعمال غير خيالية عن قانون في كندا",
    "non-fiction works about serial killers": "أعمال غير خيالية عن قتلة متسلسلون",
    "non-fiction works about united states air force": "أعمال غير خيالية عن القوات الجوية الأمريكية",
    "non-fiction works about united states navy": "أعمال غير خيالية عن البحرية الأمريكية",
    "non-fiction works": "أعمال غير خيالية",
    "Clubs in Hong Kong": "أندية في هونغ كونغ",
}


@pytest.mark.parametrize("category, expected", fast_data_drama.items(), ids=fast_data_drama.keys())
@pytest.mark.fast
def test_fast_data_drama(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected



import logging
import sys
from pathlib import Path

if _Dir := Path(__file__).parent.parent:
    sys.path.append(str(_Dir))

from ArWikiCats import resolve_arabic_category_label
from ArWikiCats.legacy_bots.legacy_resolvers_bots.bys import make_by_label
from ArWikiCats.legacy_bots.legacy_resolvers_bots.with_years_bot import Try_With_Years
from ArWikiCats.legacy_bots.legacy_resolvers_bots.year_or_typeo import (
    label_for_startwith_year_or_typeo,
)
from ArWikiCats.new_resolvers.films_resolvers.resolve_films_labels import _get_films_key_tyty_new
from ArWikiCats.new_resolvers.films_resolvers.resolve_films_labels_and_time import get_films_key_tyty_new_and_time
from ArWikiCats.new_resolvers.jobs_resolvers.mens import mens_resolver_labels
from ArWikiCats.new_resolvers.nationalities_resolvers.nationalities_v2 import resolve_by_nats
from ArWikiCats.new_resolvers.relations_resolver.nationalities_double_v2 import resolve_by_nats_double_v2
from ArWikiCats.new_resolvers.sports_resolvers.jobs_multi_sports_reslover import jobs_in_multi_sports
from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import resolve_sport_label_unified

logging.getLogger("ArWikiCats").setLevel("DEBUG")

# print(resolve_arabic_category_label("Category:2015 American television"))

# print(get_films_key_tyty_new_and_time("american adult animated television films"))
# print(get_films_key_tyty_new_and_time("1960s yemeni comedy films"))
# print("-----"*20)
# print(label_for_startwith_year_or_typeo("1960s yemeni comedy films"))
# print(_get_films_key_tyty_new("animated short film films"))
# print(_get_films_key_tyty_new("American war films"))
# print(_get_films_key_tyty_new("animated short films"))
# print(get_films_key_tyty_new_and_time("2017 American television series debuts"))
# print(resolve_by_nats("Jewish history"))
# print(resolve_by_nats("American history"))
# print(resolve_by_nats("Jewish-American history"))
# print(mens_resolver_labels("men writers"))
# print(jobs_in_multi_sports("paralympic sailors"))
# print(resolve_by_nats_double_v2("jewish german surnames"))
# print(get_con_label("by danish artists"))
# print(make_by_label("by danish artists"))
# print(Try_With_Years("2020s Dutch-language films"))
print(resolve_sport_label_unified("national football"))
# print(resolve_by_nats_double_v2("jewish history"))

# python3 D:/categories_bot/make2_new/examples/run.py
# python3 -c "from ArWikiCats import resolve_arabic_category_label; print(resolve_arabic_category_label('Category:2015 American television'))"
